local addonName,addonTable = ...
local DA = LibStub("AceAddon-3.0"):GetAddon("Skillet") -- for DebugAids.lua
--[[
Skillet: A tradeskill window replacement.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
]]--

local isRetail = WOW_PROJECT_ID == WOW_PROJECT_MAINLINE
local isClassic = WOW_PROJECT_ID == WOW_PROJECT_CLASSIC
local isBCC = WOW_PROJECT_ID == WOW_PROJECT_BURNING_CRUSADE_CLASSIC

local PT = LibStub("LibPeriodicTable-3.1")

local skillColors = {
	["unknown"]			= { r = 1.00, g = 0.00, b = 0.00, level = 5, alttext="???", cstring = "|cffff0000"},
	["optimal"]			= { r = 1.00, g = 0.50, b = 0.25, level = 4, alttext="+++", cstring = "|cffff8040"},
	["medium"]			= { r = 1.00, g = 1.00, b = 0.00, level = 3, alttext="++",	cstring = "|cffffff00"},
	["easy"]			= { r = 0.25, g = 0.75, b = 0.25, level = 2, alttext="+",	cstring = "|cff40c000"},
	["trivial"]			= { r = 0.60, g = 0.60, b = 0.60, level = 1, alttext="",	cstring = "|cff909090"},
	["header"]			= { r = 1.00, g = 0.82, b = 0,	  level = 0, alttext="",	cstring = "|cffffc800"},
	["unavailable"]		= { r = 0.3, g = 0.3, b = 0.3,	  level = 6, alttext="",	cstring = "|cff606060"},
}

--
-- function InitializeSkillLevels (which loads Skillet.db.global.SkillLevels) is 
-- at the end of this file.
--
-- Skillet-Classic table was scraped from https://wotlk.wowhead.com/, Skillet from https://www.wowhead.com/
-- using ScrapeWowhead.js (follow instructions in file)
-- provided and maintained by Matthew Hively, https://github.com/matthewhively, matthewhively@viz.com
--

--
-- Table of racial bonuses (including retail)
--
local racialList = {
	[4036]  = {["Gnome"] = 15,				-- engineering
			   ["KulTiran"] = 5},
	[7411]  = {["BloodElf"] = 10,			-- enchanting
			   ["KulTiran"] = 5},
	[25229] = {["Draenei"] = 5,				-- jewelcrafting
			   ["KulTiran"] = 5},
	[2259]  = {["Goblin"] = 15,				-- alchemy
			   ["KulTiran"] = 5},
	[2018]  = {["LightforgedDraenei"] = 15,	-- blacksmithing
			   ["DarkIronDwarf"] = 5,
			   ["KulTiran"] = 5},
	[45357] = {["Nightborne"] = 15,			-- inscription
			   ["KulTiran"] = 5},
	[2550]  = {["Pandaren"] = 15},			-- cooking
}

--
-- local function returns any racial bonus that may apply
--
local function getRacialBonus()
	local player = Skillet.currentPlayer
	local trade = Skillet.currentTrade
	local race = Skillet.db.realm.race[player]
	--DA.DEBUG(0,"getRacialBonus: trade = "..tostring(trade).." ("..tostring(GetSpellInfo(trade)).."), race= "..tostring(race))
	if racialList[trade] then
		for r, bonus in pairs(racialList[trade]) do
			--DA.DEBUG(1,"getRacialBonus: r = "..tostring(r)..", bonus= "..tostring(bonus))
			if r == race then
			DA.DEBUG(1,"getRacialBonus: bonus = "..tostring(bonus))
				return bonus
			end
		end
	end
	return 0
end

--
-- Get TradeSkill Difficulty Levels
--
-- Note: MainFrame.lua uses both inputs, other calls just use itemID.
--   Old MainFrame.lua call: GetTradeSkillLevels((recipe.itemID>0 and recipe.itemID) or -recipe.spellID)
--
function Skillet:GetTradeSkillLevels(itemID, spellID)
	--DA.DEBUG(0,"GetTradeSkillLevels("..tostring(itemID)..", "..tostring(spellID)..")")
	local a,b,c,d
	local rb = getRacialBonus()
	local skillLevels = Skillet.db.global.SkillLevels
	if itemID then 
		if tonumber(itemID) ~= nil and itemID ~= 0 then
			if self.isCraft or self.currentTrade == 7411 then  -- isCraft for Classic and BCC, Enchanting TradeID for Wrath
				DA.DEBUG(1,"GetTradeSkillLevels: itemID= "..tostring(itemID)..", spellID= "..tostring(spellID)..")")
				itemID = -itemID
			end
			self.indexTradeSkillLevel = itemID
--
-- If there is an entry in our own table, use it
--
			if skillLevels and skillLevels[itemID] then
				local levels = skillLevels[itemID]
				if type(levels) == 'table' then
					if spellID then
						if isRetail then
							levels = skillLevels[itemID][spellID]
						else
							for spell, strng in pairs(levels) do
								name = GetSpellInfo(spell)
								--DA.DEBUG(1,"GetTradeSkillLevels: name= "..tostring(name))
								if name == spellID then
									levels = strng
									break
								end
							end
						end
					end
				end
				--DA.DEBUG(1,"GetTradeSkillLevels: levels= "..tostring(levels))
				if levels and type(levels) == 'string' then
					a,b,c,d = string.split("/", levels)
					a = (tonumber(a) or 0) + rb
					b = (tonumber(b) or 0) + rb
					c = (tonumber(c) or 0) + rb
					d = (tonumber(d) or 0) + rb
					self.sourceTradeSkillLevel = 1
					return a, b, c, d
				end
			end

--
-- The TradeskillInfo addon seems to be more accurate than LibPeriodicTable-3.1
--
			if isRetail and TradeskillInfo then
				local recipeSource = Skillet.db.global.itemRecipeSource[itemID]
				if not recipeSource then
					--DA.DEBUG(1,"GetTradeSkillLevels: itemID= "..tostring(itemID)..", recipeSource= "..tostring(recipeSource))
					recipeSource = Skillet.db.global.itemRecipeSource[-itemID]
				end
				if type(recipeSource) == 'table' then
					--DA.DEBUG(1,"GetTradeSkillLevels: itemID= "..tostring(itemID)..", recipeSource= "..DA.DUMP1(recipeSource))
					for recipeID in pairs(recipeSource) do
						--DA.DEBUG(2,"GetTradeSkillLevels: recipeID= "..tostring(recipeID))
						local TSILevels = TradeskillInfo:GetCombineDifficulty(recipeID)
						if type(TSILevels) == 'table' then
							--DA.DEBUG(2,"GetTradeSkillLevels: TSILevels="..DA.DUMP1(TSILevels))
							a = (tonumber(TSILevels[1]) or 0) + rb
							b = (tonumber(TSILevels[2]) or 0) + rb
							c = (tonumber(TSILevels[3]) or 0) + rb
							d = (tonumber(TSILevels[4]) or 0) + rb
							self.sourceTradeSkillLevel = 2
							return a, b, c, d
						end
					end
				else
					--DA.DEBUG(1,"GetTradeSkillLevels: itemID= "..tostring(itemID)..", recipeSource= "..tostring(recipeSource))
				end
			end

--
-- Check LibPeriodicTable
-- Note: The itemID for Enchants is negative
--
			if PT then
				local levels = PT:ItemInSet(itemID,"TradeskillLevels")
				--DA.DEBUG(1,"GetTradeSkillLevels (PT): itemID= "..tostring(itemID)..", levels= "..tostring(levels))
				if not levels then
					itemID = -itemID
					levels = PT:ItemInSet(itemID,"TradeskillLevels")
					--DA.DEBUG(1,"GetTradeSkillLevels (PT): itemID= "..tostring(itemID)..", levels= "..tostring(levels))
				end
				if levels then
					a,b,c,d = string.split("/",levels)
					a = (tonumber(a) or 0) + rb
					b = (tonumber(b) or 0) + rb
					c = (tonumber(c) or 0) + rb
					d = (tonumber(d) or 0) + rb
					self.sourceTradeSkillLevel = 3
					return a, b, c, d
				end
			end
		elseif tonumber(itemID) == nil then
			DA.DEBUG(0,"GetTradeSkillLevels: "..tostring(itemID).." is not a number")
			self.sourceTradeSkillLevel = 4
			self.indexTradeSkillLevel = nil
			return 0, 0, 0, 0 
		end
	else
		DA.DEBUG(0,"GetTradeSkillLevels: itemID is missing")
		self.sourceTradeSkillLevel = 4
		self.indexTradeSkillLevel = nil
		return 0, 0, 0, 0 
	end
	if not self.db.global.MissingSkillLevels then
		self.db.global.MissingSkillLevels = {}
	end
	self.db.global.MissingSkillLevels[itemID] = "0/0/0/0"
	self.sourceTradeSkillLevel = 5
	return 0, 0, 0, 0 
end

function Skillet:GetTradeSkillLevelColor(itemID, rank)
	--DA.DEBUG(0,"GetTradeSkillLevelColor("..tostring(itemID)..", "..tostring(rank)")")
	if itemID then
		local orange, yellow, green, gray = self:GetTradeSkillLevels(itemID)
		if rank >= gray then return skillColors["trivial"] end
		if rank >= green then return skillColors["easy"] end
		if rank >= yellow then return skillColors["moderate"] end
		if rank >= orange then return skillColors["optimal"] end
	end
	return skillColors["unknown"]
end

function Skillet:AddTradeSkillLevels(itemID, orange, yellow, green, gray, spellID)
	DA.DEBUG(0,"AddTradeSkillLevels("..tostring(itemID)..", "..tostring(orange)..", "..tostring(yellow)..", "..tostring(green)..", "..tostring(gray)..", "..tostring(spellID)..")")
	local skillLevels = Skillet.db.global.SkillLevels
--
-- We should add some sanity checking
--
	if itemID and spellID then
		if not skillLevels[itemID] then 
			skillLevels[itemID] = {}
		end
		skillLevels[itemID][spellID] = tostring(orange).."/"..tostring(yellow).."/"..tostring(green).."/"..tostring(gray)
	elseif itemID then
		skillLevels[itemID] = tostring(orange).."/"..tostring(yellow).."/"..tostring(green).."/"..tostring(gray)
	end
end

function Skillet:DelTradeSkillLevels(itemID)
	DA.DEBUG(0,"DelTradeSkillLevels("..tostring(itemID)..")")
	local skillLevels = Skillet.db.global.SkillLevels
	if itemID then
--
-- We could add some additional checking
--
		skillLevels[itemID] = nil
	end
end

--
-- Print the TradeSkillLevels(itemID) result including the actual index and the source.
--
-- index will be itemID or if the current profession is Enchanting, -itemID
--
-- source will be:
--    1 if from Skillet.db.global.SkillLevels
--    2 if from TradeskillInfo
--    3 if from LibPeriodicTable
--    4 if itemID was missing or not a number
--    5 if it wasn't found (and was added to Skillet.db.global.MissingSkillLevels)
--
function Skillet:PrintTradeSkillLevels(itemID, spellID)
	--DA.DEBUG(0,"PrintTradeSkillLevels("..tostring(itemID)..", "..tostring(spellID)..")")
	if itemID then
		local orange, yellow, green, gray = self:GetTradeSkillLevels(itemID, spellID)
		DA.MARK3("PrintTradeSkillLevels: itemID= "..tostring(itemID)..", spellID= "..tostring(spellID))
		DA.MARK3("PrintTradeSkillLevels: index= "..tostring(self.indexTradeSkillLevel)..", source= "..tostring(self.sourceTradeSkillLevel))
		DA.MARK3("PrintTradeSkillLevels: levels= "..tostring(orange).."/"..tostring(yellow).."/"..tostring(green).."/"..tostring(gray))
	end
end

--
-- Our own table of skill levels (Skillet.db.global.SkillLevels)
--   1) can be maintained manually
--      To scrape from Wowhead: Follow instructions in ScrapeWowhead.js
--
--   2) can be maintained with an external addon (using AddTradeSkillLevels, DelTradeSkillLevels)
--
-- Each entry is either [itemID] = "orange/yellow/green/gray" or 
--   a table of spellIDs with the same format
--   [itemID] = {[spellID1] = "orange/yellow/green/gray", [spellID2] = "orange/yellow/green/gray"},
--
--   itemID is the item made by the recipe or the recipeID of the Enchant
--   spellID(s) are the numeric recipeID(s) of each recipe that produces the itemID
--   orange is the (numeric) skill level below which recipe is orange
--   yellow is the (numeric) skill level below which the recipe is yellow
--   green  is the (numeric) skill level below which the recipe is green
--   gray   is the (numeric) skill level above which the recipe is gray
--
-- A global table, Skillet.db.global.MissingSkillLevels, is added to when
-- no other entry is found. The format of this table is the same as
-- the table Skillet.db.global.SkillLevels to facilitate adding to this table.
--
-- InitializeSkillLevels is only called if the table does not exist.
--
-- Force refresh with '/skillet initskilllevels'
-- or '/run Skillet:InitializeSkillLevels()'
-- or '/run Skillet.db.global.SkillLevels = nil'
--
function Skillet:InitializeSkillLevels()
	self.db.global.SkillLevels = {
--		      "orange/yellow/green/gray",
		[0] = "0/0/0/0",

-- https://wotlk.wowhead.com/alchemy#recipes
-- skipping spellID: 2336 - Elixir of Tongues
-- skipping spellID: 17579 - Greater Holy Protection Potion
-- skipping spellID: 54020 - Transmute: Eternal Might
-- number recipes: 251 
[-60893] = "400/415/422/430",
[118] = "1/55/75/95",
[858] = "55/85/105/125",
[929] = "110/135/155/175",
[1710] = "155/175/195/215",
[2454] = "1/55/75/95",
[2455] = "25/65/85/105",
[2456] = "40/70/90/110",
[2457] = "50/80/100/120",
[2458] = "50/80/100/120",
[2459] = "60/90/110/130",
[3382] = "15/60/80/100",
[3383] = "90/120/140/160",
[3384] = "110/135/155/175",
[3385] = "120/145/165/185",
[3386] = "120/145/165/185",
[3387] = "250/275/295/315",
[3388] = "125/150/170/190",
[3389] = "130/155/175/195",
[3390] = "140/165/185/205",
[3391] = "150/175/195/215",
[3577] = "225/240/260/280",
[3823] = "165/185/205/225",
[3824] = "165/190/210/230",
[3825] = "175/195/215/235",
[3826] = "180/200/220/240",
[3827] = "160/180/200/220",
[3828] = "195/215/235/255",
[3829] = "200/220/240/260",
[3928] = "215/230/250/270",
[4596] = "50/80/100/120",
[4623] = "215/230/250/270",
[5631] = "60/90/110/130",
[5633] = "175/195/215/235",
[5634] = "150/175/195/215",
[5996] = "90/120/140/160",
[5997] = "1/55/75/95",
[6037] = "225/240/260/280",
[6048] = "135/160/180/200",
[6049] = "165/210/230/250",
[6050] = "190/205/225/245",
[6051] = "100/130/150/170",
[6052] = "190/210/230/250",
[6149] = "205/220/240/260",
[6370] = "80/80/90/100",
[6371] = "130/150/160/170",
[6372] = "100/130/150/170",
[6373] = "140/165/185/205",
[6662] = "90/120/140/160",
[7068] = "300/301/305/310",
[7076] = {[17560] = "275/275/282/290", [17565] = "275/275/282/290"},
[7078] = "275/275/282/290",
[7080] = {[17561] = "275/275/282/290", [17563] = "275/275/282/290"},
[7082] = "275/275/282/290",
[8827] = "400/415/422/430",
[8949] = "185/205/225/245",
[8951] = "195/215/235/255",
[8956] = "205/220/240/260",
[9030] = "215/225/245/265",
[9036] = "210/225/245/265",
[9061] = "210/225/245/265",
[9088] = "240/255/275/295",
[9144] = "225/240/260/280",
[9149] = "225/240/260/280",
[9154] = "230/245/265/285",
[9155] = "235/250/270/290",
[9172] = "235/250/270/290",
[9179] = "235/250/270/290",
[9187] = "240/255/275/295",
[9197] = "240/255/275/295",
[9206] = "245/260/280/300",
[9210] = "245/260/280/300",
[9224] = "250/265/285/305",
[9233] = "250/265/285/305",
[9264] = "250/265/285/305",
[10592] = "200/220/240/260",
[12190] = "230/245/265/285",
[12360] = "275/275/282/290",
[12803] = "275/275/282/290",
[12808] = "275/275/282/290",
[13423] = "250/250/255/260",
[13442] = "255/270/290/310",
[13443] = "260/275/295/315",
[13444] = "295/310/330/350",
[13445] = "265/280/300/320",
[13446] = "275/290/310/330",
[13447] = "270/285/305/325",
[13452] = "280/295/315/335",
[13453] = "275/290/310/330",
[13454] = "285/300/320/340",
[13455] = "280/295/315/335",
[13456] = "290/305/325/345",
[13457] = "290/305/325/345",
[13458] = "290/305/325/345",
[13459] = "290/305/325/345",
[13461] = "290/305/325/345",
[13462] = "285/300/320/340",
[13503] = "300/365/372/380",
[13506] = "300/315/322/330",
[13510] = "300/315/322/330",
[13511] = "300/315/322/330",
[13512] = "300/315/322/330",
[13513] = "300/315/322/330",
[17708] = "190/210/230/250",
[18253] = "300/310/320/330",
[18294] = "215/230/250/270",
[19931] = "300/315/322/330",
[20002] = "275/290/310/330",
[20004] = "290/305/325/345",
[20007] = "275/290/310/330",
[20008] = "285/300/320/340",
[21546] = "250/265/285/305",
[21884] = {[28566] = "350/365/372/380", [28582] = "300/375/377/380"},
[21885] = {[28567] = "350/365/372/380", [28580] = "300/375/377/380"},
[21886] = "300/375/377/380",
[22451] = "350/365/372/380",
[22452] = {[28568] = "350/365/372/380", [28584] = "300/375/377/380"},
[22456] = "300/375/377/380",
[22457] = "300/375/377/380",
[22823] = "305/320/327/335",
[22824] = "305/320/327/335",
[22825] = "310/325/332/340",
[22826] = "315/330/337/345",
[22827] = "320/335/342/350",
[22828] = "320/335/342/350",
[22829] = "325/340/347/355",
[22830] = "325/340/347/355",
[22831] = "330/345/352/360",
[22832] = "340/355/362/370",
[22833] = "345/360/367/375",
[22834] = "345/360/367/375",
[22835] = "350/365/372/380",
[22836] = "350/365/372/380",
[22837] = "350/365/372/380",
[22838] = "350/365/372/380",
[22839] = "350/365/372/380",
[22840] = "355/370/375/380",
[22841] = "360/375/377/380",
[22842] = "360/375/377/380",
[22844] = "360/375/377/380",
[22845] = "360/375/377/380",
[22846] = "360/375/377/380",
[22847] = "360/375/377/380",
[22848] = "365/375/377/380",
[22849] = "365/375/377/380",
[22850] = "300/375/377/380",
[22851] = "300/375/377/380",
[22853] = "300/375/377/380",
[22854] = "300/375/377/380",
[22861] = "300/375/377/380",
[22866] = "300/375/377/380",
[22871] = "335/350/357/365",
[23571] = "350/365/372/380",
[25867] = "350/365/372/380",
[25868] = "350/365/372/380",
[28100] = "300/315/322/330",
[28101] = "310/325/332/340",
[28102] = "300/315/322/330",
[28103] = "300/315/322/330",
[28104] = "315/330/337/345",
[31080] = "325/340/347/355",
[31676] = "345/360/367/375",
[31677] = "360/375/377/380",
[31679] = "335/350/357/365",
[32062] = "310/325/332/340",
[32063] = "320/335/342/350",
[32067] = "320/335/342/350",
[32068] = "330/345/352/360",
[32839] = "360/360/370/380",
[32849] = "360/360/370/380",
[32850] = "360/360/370/380",
[32851] = "360/360/370/380",
[32852] = "360/360/370/380",
[33208] = "375/390/397/405",
[33447] = "405/410/417/425",
[33448] = "410/415/422/430",
[34440] = "325/335/342/350",
[35622] = {[53774] = "300/405/415/425", [53776] = "300/405/415/425"},
[35623] = {[53781] = "300/405/415/425", [53783] = "300/405/415/425"},
[35624] = {[53777] = "300/405/415/425", [53779] = "300/405/415/425"},
[35625] = {[53775] = "300/405/415/425", [53780] = "300/405/415/425"},
[35627] = {[53771] = "300/405/415/425", [53782] = "300/405/415/425"},
[35748] = "375/380/385/390",
[35749] = "375/380/385/390",
[35750] = "375/380/385/390",
[35751] = "375/380/385/390",
[36860] = {[53773] = "300/405/415/425", [53784] = "300/405/415/425"},
[36919] = "300/440/452/465",
[36922] = "300/450/452/465",
[36925] = "300/450/452/465",
[36928] = "300/450/452/465",
[36931] = "300/450/452/465",
[36934] = "300/450/452/465",
[39666] = "395/400/407/415",
[39671] = "350/360/370/380",
[40067] = "360/365/375/385",
[40068] = "355/365/375/385",
[40070] = "365/375/382/390",
[40072] = "385/390/395/400",
[40073] = "385/390/395/400",
[40076] = "375/380/385/390",
[40077] = "400/415/422/430",
[40078] = "390/395/400/405",
[40079] = "375/380/385/390",
[40081] = "380/385/390/395",
[40087] = "400/415/422/430",
[40093] = "395/415/422/430",
[40097] = "400/415/422/430",
[40109] = "400/415/422/430",
[40195] = "375/380/385/390",
[40211] = "400/415/422/430",
[40212] = "400/415/422/430",
[40213] = "400/410/415/420",
[40214] = "400/410/415/420",
[40215] = "400/410/415/420",
[40216] = "400/410/415/420",
[40217] = "400/410/415/420",
[41163] = "395/420/430/440",
[41266] = "430/440/445/450",
[41334] = "425/435/440/445",
[43569] = "410/410/412/415",
[43570] = "410/415/417/420",
[44322] = "400/420/425/430",
[44323] = "400/420/425/430",
[44324] = "400/420/425/430",
[44325] = "400/415/422/430",
[44327] = "400/415/422/430",
[44328] = "400/415/422/430",
[44329] = "400/415/422/430",
[44330] = "400/415/422/430",
[44331] = "400/415/422/430",
[44332] = "395/400/407/415",
[44939] = "385/390/395/400",
[44958] = "375/380/385/390",
[45621] = "135/160/180/200",
[46376] = "435/450/457/465",
[46377] = "435/450/457/465",
[46378] = "435/450/457/465",
[46379] = "435/450/457/465",
[47499] = "425/440/445/450",
		
-- https://wotlk.wowhead.com/blacksmithing#recipes
-- skipping spellID: 16965 - Bleakwood Hew
-- skipping spellID: 16986 - Blood Talon
-- skipping spellID: 16987 - Darkspear
-- skipping spellID: 16967 - Inlaid Thorium Hammer
-- skipping spellID: 8366 - Ironforge Chain
-- skipping spellID: 8368 - Ironforge Gauntlets
-- skipping spellID: 9942 - Mithril Scale Gloves
-- skipping spellID: 2671 - Rough Bronze Bracers
-- skipping spellID: 16980 - Rune Edge
-- skipping spellID: 16960 - Thorium Greatsword
-- number recipes: 504
[-55628] = "400/400/400/400",
[-55641] = "400/400/400/400",
[2844] = "15/55/75/95",
[2845] = "20/60/80/100",
[2847] = "25/65/85/105",
[2848] = "110/140/155/170",
[2849] = "115/145/160/175",
[2850] = "120/150/165/180",
[2851] = "35/75/95/115",
[2852] = "1/50/70/90",
[2853] = "1/20/40/60",
[2854] = "90/115/127/140",
[2857] = "70/110/130/150",
[2862] = "1/15/35/55",
[2863] = "65/65/72/80",
[2864] = "80/120/140/160",
[2865] = "105/145/160/175",
[2866] = "105/145/160/175",
[2868] = "120/150/165/180",
[2869] = "130/160/175/190",
[2870] = "145/175/190/205",
[2871] = "125/125/132/140",
[3239] = "1/15/35/55",
[3240] = "65/65/72/80",
[3241] = "125/125/132/140",
[3469] = "20/60/80/100",
[3470] = "25/45/65/85",
[3471] = "35/75/95/115",
[3472] = "40/80/100/120",
[3473] = "45/85/105/125",
[3474] = "60/100/120/140",
[3478] = "75/75/87/100",
[3480] = "110/140/155/170",
[3481] = "125/155/170/185",
[3482] = "130/160/175/190",
[3483] = "135/165/180/195",
[3484] = "145/175/190/205",
[3485] = "150/180/195/210",
[3486] = "125/125/137/150",
[3487] = "95/135/155/175",
[3488] = "35/75/95/115",
[3489] = "70/110/130/150",
[3490] = "125/155/170/185",
[3491] = "130/160/175/190",
[3492] = "145/175/190/205",
[3835] = "165/190/202/215",
[3836] = "170/195/207/220",
[3837] = "190/215/227/240",
[3840] = "160/185/197/210",
[3841] = "175/200/212/225",
[3842] = "155/180/192/205",
[3843] = "170/195/207/220",
[3844] = "180/205/217/230",
[3845] = "195/220/232/245",
[3846] = "185/210/222/235",
[3847] = "200/225/237/250",
[3848] = "105/135/150/165",
[3849] = "160/185/197/210",
[3850] = "175/200/212/225",
[3851] = "155/180/192/205",
[3852] = "170/195/207/220",
[3853] = "180/205/217/230",
[3854] = "200/225/237/250",
[3855] = "185/210/222/235",
[3856] = "200/225/237/250",
[5540] = "110/140/155/170",
[5541] = "140/170/185/200",
[6040] = "185/210/222/235",
[6041] = "190/215/227/240",
[6042] = "150/180/195/210",
[6043] = "165/190/202/215",
[6214] = "65/105/125/145",
[6338] = "100/105/107/110",
[6350] = "95/125/140/155",
[6731] = "100/140/160/180",
[7071] = "150/150/152/155",
[7166] = "30/70/90/110",
[7913] = "160/185/197/210",
[7914] = "160/185/197/210",
[7915] = "175/200/212/225",
[7916] = "180/205/217/230",
[7917] = "185/210/222/235",
[7918] = "205/225/235/245",
[7919] = "205/225/235/245",
[7920] = "210/230/240/250",
[7921] = "210/230/240/250",
[7922] = "215/235/245/255",
[7924] = "215/235/245/255",
[7926] = "220/240/250/260",
[7927] = "220/240/250/260",
[7928] = "225/245/255/265",
[7929] = "230/250/260/270",
[7930] = "230/250/260/270",
[7931] = "230/250/260/270",
[7932] = "235/255/265/275",
[7933] = "235/255/265/275",
[7934] = "245/255/265/275",
[7935] = "240/260/270/280",
[7936] = "245/265/275/285",
[7937] = "245/265/275/285",
[7938] = "225/245/255/265",
[7939] = "245/265/275/285",
[7941] = "210/235/247/260",
[7942] = "220/245/257/270",
[7943] = "225/250/262/275",
[7944] = "240/265/277/290",
[7945] = "230/255/267/280",
[7946] = "245/270/282/295",
[7947] = "255/280/292/305",
[7954] = "235/260/272/285",
[7955] = "30/70/90/110",
[7956] = "125/155/170/185",
[7957] = "130/160/175/190",
[7958] = "135/165/180/195",
[7959] = "250/275/287/300",
[7960] = "260/285/297/310",
[7961] = "245/270/282/295",
[7963] = "200/225/237/250",
[7964] = "200/200/205/210",
[7965] = "200/200/205/210",
[7966] = "200/200/205/210",
[7967] = "215/235/245/255",
[7969] = "235/255/265/275",
[9060] = "200/225/237/250",
[9366] = "205/225/235/245",
[10421] = "1/15/35/55",
[10423] = "155/180/192/205",
[11128] = "150/155/157/160",
[11144] = "200/205/207/210",
[11604] = "285/305/315/325",
[11605] = "280/300/310/320",
[11606] = "270/290/300/310",
[11607] = "275/295/305/315",
[11608] = "265/285/295/305",
[12259] = "180/205/217/230",
[12260] = "190/215/227/240",
[12404] = "250/255/257/260",
[12405] = "250/270/280/290",
[12406] = "250/270/280/290",
[12408] = "255/275/285/295",
[12409] = "280/300/310/320",
[12410] = "280/300/310/320",
[12414] = "300/320/330/340",
[12415] = "270/290/300/310",
[12416] = "260/280/290/300",
[12417] = "295/315/325/335",
[12418] = "285/305/315/325",
[12419] = "290/310/320/330",
[12420] = "300/320/330/340",
[12422] = "300/320/330/340",
[12424] = "265/285/295/305",
[12425] = "270/290/300/310",
[12426] = "295/315/325/335",
[12427] = "295/315/325/335",
[12428] = "265/285/295/305",
[12429] = "300/320/330/340",
[12610] = "300/320/330/340",
[12611] = "300/320/330/340",
[12612] = "300/320/330/340",
[12613] = "300/320/330/340",
[12614] = "300/320/330/340",
[12618] = "300/320/330/340",
[12619] = "300/320/330/340",
[12620] = "300/320/330/340",
[12624] = "270/290/300/310",
[12625] = "290/310/320/330",
[12628] = "285/305/315/325",
[12631] = "290/310/320/330",
[12632] = "295/315/325/335",
[12633] = "300/320/330/340",
[12636] = "300/320/330/340",
[12639] = "300/320/330/340",
[12640] = "300/320/330/340",
[12641] = "300/320/330/340",
[12643] = "250/255/257/260",
[12644] = "250/255/257/260",
[12645] = "275/295/305/315",
[12773] = "275/300/312/325",
[12774] = "275/300/312/325",
[12775] = "280/305/317/330",
[12776] = "280/305/317/330",
[12777] = "280/305/317/330",
[12781] = "285/310/322/335",
[12782] = "290/315/327/340",
[12783] = "300/320/330/340",
[12784] = "300/320/330/340",
[12790] = "300/320/330/340",
[12792] = "290/315/327/340",
[12794] = "300/320/330/340",
[12796] = "300/320/330/340",
[12797] = "300/320/330/340",
[12798] = "300/320/330/340",
[15869] = "100/100/110/120",
[15870] = "150/150/160/170",
[15871] = "200/200/210/220",
[15872] = "275/275/280/285",
[16206] = "275/275/280/285",
[16988] = "300/320/330/340",
[16989] = "295/315/325/335",
[17013] = "300/320/330/340",
[17014] = "295/315/325/335",
[17015] = "300/320/330/340",
[17016] = "300/320/330/340",
[17193] = "300/325/337/350",
[17704] = "190/215/227/240",
[18262] = "300/300/310/320",
[19043] = "290/310/320/330",
[19048] = "300/320/330/340",
[19051] = "290/310/320/330",
[19057] = "300/320/330/340",
[19148] = "300/320/330/340",
[19164] = "300/320/330/340",
[19166] = "300/320/330/340",
[19167] = "300/320/330/340",
[19168] = "300/320/330/340",
[19169] = "300/320/330/340",
[19170] = "300/320/330/340",
[19690] = "300/320/330/340",
[19691] = "300/320/330/340",
[19692] = "300/320/330/340",
[19693] = "300/320/330/340",
[19694] = "300/320/330/340",
[19695] = "300/320/330/340",
[20039] = "300/320/330/340",
[20549] = "300/320/330/340",
[20550] = "300/320/330/340",
[20551] = "300/320/330/340",
[22191] = "300/320/330/340",
[22194] = "300/320/330/340",
[22195] = "300/320/330/340",
[22196] = "300/320/330/340",
[22197] = "300/320/330/340",
[22198] = "300/320/330/340",
[22383] = "300/320/330/340",
[22384] = "300/320/330/340",
[22385] = "300/320/330/340",
[22669] = "300/320/330/340",
[22670] = "300/320/330/340",
[22671] = "300/320/330/340",
[22762] = "300/320/330/340",
[22763] = "300/320/330/340",
[22764] = "300/320/330/340",
[23482] = "300/310/320/330",
[23484] = "305/315/325/335",
[23487] = "315/325/335/345",
[23488] = "315/325/335/345",
[23489] = "325/335/345/355",
[23490] = "320/330/340/350",
[23491] = "310/320/330/340",
[23493] = "300/310/320/330",
[23494] = "315/325/335/345",
[23497] = "310/320/330/340",
[23498] = "315/325/335/345",
[23499] = "320/330/340/350",
[23502] = "325/335/345/355",
[23503] = "330/340/350/360",
[23504] = "330/340/350/360",
[23505] = "335/345/355/365",
[23506] = "335/345/355/365",
[23507] = "340/350/360/370",
[23508] = "335/345/355/365",
[23509] = "360/370/380/390",
[23510] = "355/365/375/385",
[23511] = "355/365/375/385",
[23512] = "365/375/385/395",
[23513] = "365/375/385/395",
[23514] = "360/370/380/390",
[23515] = "350/360/370/380",
[23516] = "355/365/375/385",
[23517] = "360/370/380/390",
[23518] = "360/370/380/390",
[23519] = "365/375/385/395",
[23520] = "365/375/385/395",
[23521] = "365/375/385/395",
[23522] = "370/380/390/400",
[23523] = "360/370/380/390",
[23524] = "360/370/380/390",
[23525] = "365/375/385/395",
[23526] = "370/380/390/400",
[23527] = "370/380/390/400",
[23528] = "300/300/305/310",
[23529] = "350/350/355/360",
[23530] = "360/370/380/390",
[23531] = "365/375/385/395",
[23532] = "365/375/385/395",
[23533] = "365/375/385/395",
[23534] = "365/375/385/395",
[23535] = "365/375/385/395",
[23536] = "365/375/385/395",
[23537] = "365/375/385/395",
[23538] = "365/375/385/395",
[23539] = "365/375/385/395",
[23540] = "365/375/385/395",
[23541] = "365/375/385/395",
[23542] = "365/375/385/395",
[23543] = "365/375/385/395",
[23544] = "365/375/385/395",
[23546] = "365/375/385/395",
[23554] = "365/375/385/395",
[23555] = "365/375/385/395",
[23556] = "365/375/385/395",
[23559] = "325/325/330/335",
[23563] = "350/360/370/380",
[23564] = "375/385/395/405",
[23565] = "375/385/395/405",
[23575] = "340/340/345/350",
[23576] = "375/375/375/375",
[25521] = "350/350/355/360",
[25843] = "300/300/305/310",
[25844] = "350/350/355/360",
[25845] = "360/365/370/375",
[28420] = "300/300/305/310",
[28421] = "350/350/355/360",
[28425] = "350/360/370/380",
[28426] = "375/385/395/405",
[28427] = "375/385/395/405",
[28428] = "350/360/370/380",
[28429] = "375/385/395/405",
[28430] = "375/385/395/405",
[28431] = "350/360/370/380",
[28432] = "375/385/395/405",
[28433] = "375/385/395/405",
[28434] = "350/360/370/380",
[28435] = "375/385/395/405",
[28436] = "375/385/395/405",
[28437] = "350/360/370/380",
[28438] = "375/385/395/405",
[28439] = "375/385/395/405",
[28440] = "350/360/370/380",
[28441] = "375/385/395/405",
[28442] = "375/385/395/405",
[28483] = "350/360/370/380",
[28484] = "375/385/395/405",
[28485] = "375/385/395/405",
[29201] = "100/130/145/160",
[29202] = "200/220/230/240",
[29203] = "300/320/330/340",
[29204] = "350/360/370/380",
[30031] = "375/385/395/405",
[30032] = "375/385/395/405",
[30033] = "375/385/395/405",
[30034] = "375/385/395/405",
[30069] = "260/280/290/300",
[30070] = "260/280/290/300",
[30071] = "260/280/290/300",
[30072] = "260/280/290/300",
[30073] = "260/280/290/300",
[30074] = "330/340/350/360",
[30076] = "330/340/350/360",
[30077] = "330/340/350/360",
[30086] = "330/340/350/360",
[30087] = "330/340/350/360",
[30088] = "330/340/350/360",
[30089] = "330/340/350/360",
[30093] = "330/340/350/360",
[31364] = "375/385/395/405",
[31367] = "375/385/395/405",
[31368] = "375/385/395/405",
[31369] = "375/385/395/405",
[31370] = "375/385/395/405",
[31371] = "375/385/395/405",
[32401] = "375/385/395/405",
[32402] = "375/385/395/405",
[32403] = "375/385/395/405",
[32404] = "375/385/395/405",
[32568] = "375/385/395/405",
[32570] = "375/385/395/405",
[32571] = "375/385/395/405",
[32573] = "375/385/395/405",
[32854] = "365/375/385/395",
[33173] = "365/375/385/395",
[33185] = "335/345/350/355",
[33791] = "35/75/95/115",
[34377] = "365/375/392/410",
[34378] = "365/375/392/410",
[34379] = "365/375/392/410",
[34380] = "365/375/392/410",
[39083] = "360/370/375/380",
[39084] = "370/375/380/385",
[39085] = "375/380/385/390",
[39086] = "370/375/380/385",
[39087] = "350/360/370/380",
[39088] = "350/360/370/380",
[40668] = "360/370/375/380",
[40669] = "395/400/405/410",
[40670] = "390/395/400/405",
[40671] = "400/405/410/415",
[40672] = "400/405/410/415",
[40673] = "405/410/415/420",
[40674] = "395/400/405/410",
[40675] = "405/410/415/420",
[40942] = "375/380/385/390",
[40943] = "395/400/405/410",
[40949] = "380/385/390/395",
[40950] = "385/390/395/400",
[40951] = "385/390/395/400",
[40952] = "390/395/400/405",
[40953] = "395/400/405/410",
[40954] = "400/405/410/415",
[40955] = "400/405/410/415",
[40956] = "375/395/400/405",
[40957] = "375/405/410/415",
[40958] = "375/410/415/420",
[40959] = "375/415/420/425",
[41113] = "410/415/420/425",
[41114] = "415/420/425/430",
[41116] = "410/415/420/425",
[41117] = "390/395/400/405",
[41126] = "395/400/405/410",
[41127] = "400/405/410/415",
[41128] = "405/410/415/420",
[41129] = "415/420/425/430",
[41181] = "390/395/400/405",
[41182] = "395/400/405/410",
[41183] = "400/405/410/415",
[41184] = "405/410/415/420",
[41185] = "410/415/420/425",
[41186] = "415/420/425/430",
[41187] = "415/420/425/430",
[41188] = "415/420/425/430",
[41189] = "415/420/425/430",
[41190] = "415/420/425/430",
[41239] = "380/385/390/395",
[41240] = "380/385/390/395",
[41241] = "385/390/395/400",
[41242] = "385/390/395/400",
[41243] = "390/395/400/405",
[41245] = "405/415/420/425",
[41257] = "440/450/460/470",
[41344] = "425/435/445/455",
[41345] = "425/435/445/455",
[41346] = "425/435/445/455",
[41347] = "425/435/445/455",
[41348] = "420/430/440/450",
[41349] = "420/430/440/450",
[41350] = "425/435/445/455",
[41351] = "420/430/440/450",
[41352] = "420/430/440/450",
[41353] = "425/435/445/455",
[41354] = "420/425/430/435",
[41355] = "420/425/430/435",
[41356] = "420/430/440/450",
[41357] = "420/430/440/450",
[41383] = "440/450/460/470",
[41384] = "440/450/460/470",
[41386] = "440/450/460/470",
[41387] = "440/450/460/470",
[41388] = "440/450/460/470",
[41391] = "440/450/460/470",
[41392] = "440/450/460/470",
[41394] = "440/450/460/470",
[41611] = "415/420/425/430",
[41745] = "420/425/430/435",
[41974] = "360/370/375/380",
[41975] = "370/380/385/390",
[41976] = "420/425/430/435",
[42435] = "440/450/460/470",
[42443] = "410/415/420/425",
[42500] = "420/425/430/435",
[42508] = "440/450/460/470",
[42723] = "420/425/430/435",
[42724] = "420/430/440/450",
[42725] = "425/435/445/455",
[42726] = "425/435/445/455",
[42727] = "420/430/440/450",
[42728] = "425/435/445/455",
[42729] = "420/430/440/450",
[42730] = "420/430/440/450",
[43586] = "425/435/445/455",
[43587] = "420/430/440/450",
[43588] = "420/430/440/450",
[43853] = "430/435/440/445",
[43854] = "350/360/365/370",
[43860] = "395/400/405/410",
[43864] = "400/405/410/415",
[43865] = "405/410/415/420",
[43870] = "415/420/425/430",
[43871] = "410/415/420/425",
[44936] = "450/455/460/465",
[45085] = "440/450/460/470",
[45550] = "450/455/465/475",
[45551] = "450/455/465/475",
[45552] = "450/455/465/475",
[45559] = "450/455/465/475",
[45560] = "450/455/465/475",
[45561] = "450/455/465/475",
[47570] = "450/460/467/475",
[47571] = "450/460/467/475",
[47572] = "450/460/467/475",
[47573] = "450/460/467/475",
[47574] = "450/460/467/475",
[47575] = "450/460/467/475",
[47589] = "450/460/467/475",
[47590] = "450/460/467/475",
[47591] = "450/460/467/475",
[47592] = "450/460/467/475",
[47593] = "450/460/467/475",
[47594] = "450/460/467/475",
[49902] = "450/475/487/500",
[49903] = "450/475/487/500",
[49904] = "450/475/487/500",
[49905] = "450/475/487/500",
[49906] = "450/475/487/500",
[49907] = "450/475/487/500",
		
-- https://wotlk.wowhead.com/enchanting#recipes
-- skipping spellID: 28021 - Arcane Dust
-- skipping spellID: 44612 - Enchant Gloves - Greater Blasting
-- skipping spellID: 62257 - Enchant Weapon - Titanguard
-- number recipes: 296
[-7418] = "1/70/90/110",
[-7420] = "15/70/90/110",
[-7421] = "1/5/7/10",
[-7426] = "40/90/110/130",
[-7428] = "1/80/100/120",
[-7443] = "20/80/100/120",
[-7454] = "45/95/115/135",
[-7457] = "50/100/120/140",
[-7745] = "100/130/150/170",
[-7748] = "60/105/125/145",
[-7766] = "60/105/125/145",
[-7771] = "70/110/130/150",
[-7776] = "80/115/135/155",
[-7779] = "80/115/135/155",
[-7782] = "80/115/135/155",
[-7786] = "90/120/140/160",
[-7788] = "90/120/140/160",
[-7793] = "100/130/150/170",
[-7795] = "100/130/150/170",
[-7857] = "120/145/165/185",
[-7859] = "120/145/165/185",
[-7861] = "125/150/170/190",
[-7863] = "125/150/170/190",
[-7867] = "125/150/170/190",
[-13378] = "105/130/150/170",
[-13380] = "110/135/155/175",
[-13419] = "110/135/155/175",
[-13421] = "115/140/160/180",
[-13464] = "115/140/160/180",
[-13485] = "130/155/175/195",
[-13501] = "130/155/175/195",
[-13503] = "140/165/185/205",
[-13522] = "135/160/180/200",
[-13529] = "145/170/190/210",
[-13536] = "140/165/185/205",
[-13538] = "140/165/185/205",
[-13607] = "145/170/190/210",
[-13612] = "145/170/190/210",
[-13617] = "145/170/190/210",
[-13620] = "145/170/190/210",
[-13622] = "150/175/195/215",
[-13626] = "150/175/195/215",
[-13628] = "150/175/195/215",
[-13631] = "155/175/195/215",
[-13635] = "155/175/195/215",
[-13637] = "160/180/200/220",
[-13640] = "160/180/200/220",
[-13642] = "165/185/205/225",
[-13644] = "170/190/210/230",
[-13646] = "170/190/210/230",
[-13648] = "170/190/210/230",
[-13653] = "175/195/215/235",
[-13655] = "175/195/215/235",
[-13657] = "175/195/215/235",
[-13659] = "180/200/220/240",
[-13661] = "180/200/220/240",
[-13663] = "185/205/225/245",
[-13687] = "190/210/230/250",
[-13689] = "195/215/235/255",
[-13693] = "195/215/235/255",
[-13695] = "200/220/240/260",
[-13698] = "200/220/240/260",
[-13700] = "200/220/240/260",
[-13702] = "200/220/240/260",
[-13746] = "205/225/245/265",
[-13794] = "205/225/245/265",
[-13815] = "210/230/250/270",
[-13817] = "210/230/250/270",
[-13822] = "210/230/250/270",
[-13836] = "215/235/255/275",
[-13841] = "215/235/255/275",
[-13846] = "220/240/260/280",
[-13858] = "220/240/260/280",
[-13868] = "225/245/265/285",
[-13882] = "225/245/265/285",
[-13887] = "225/245/265/285",
[-13890] = "225/245/265/285",
[-13898] = "265/285/305/325",
[-13905] = "230/250/270/290",
[-13915] = "230/250/270/290",
[-13917] = "230/250/270/290",
[-13931] = "235/255/275/295",
[-13933] = "235/255/275/295",
[-13935] = "235/255/275/295",
[-13937] = "240/260/280/300",
[-13939] = "240/260/280/300",
[-13941] = "245/265/285/305",
[-13943] = "245/265/285/305",
[-13945] = "245/265/285/305",
[-13947] = "250/270/290/310",
[-13948] = "250/270/290/310",
[-14293] = "10/75/95/115",
[-14807] = "70/110/130/150",
[-14809] = "155/175/195/215",
[-14810] = "175/195/215/235",
[-15596] = "265/285/305/325",
[-17180] = "250/250/255/260",
[-17181] = "250/250/255/260",
[-20008] = "255/275/295/315",
[-20009] = "270/290/310/330",
[-20010] = "295/310/325/340",
[-20011] = "300/310/325/340",
[-20012] = "270/290/310/330",
[-20013] = "295/310/325/340",
[-20014] = "265/285/305/325",
[-20015] = "285/300/317/335",
[-20016] = "280/300/320/340",
[-20017] = "265/285/305/325",
[-20020] = "260/280/300/320",
[-20023] = "295/310/325/340",
[-20024] = "275/295/315/335",
[-20025] = "300/310/325/340",
[-20026] = "275/295/315/335",
[-20028] = "290/305/322/340",
[-20029] = "285/300/317/335",
[-20030] = "295/310/325/340",
[-20031] = "300/310/325/340",
[-20032] = "300/310/325/340",
[-20033] = "295/310/325/340",
[-20034] = "300/310/325/340",
[-20035] = "300/310/325/340",
[-20036] = "300/310/325/340",
[-20051] = "290/305/322/340",
[-21931] = "190/210/230/250",
[-22749] = "300/310/325/340",
[-22750] = "300/310/325/340",
[-23799] = "290/305/322/340",
[-23800] = "290/305/322/340",
[-23801] = "290/305/322/340",
[-23802] = "300/310/325/340",
[-23803] = "300/310/325/340",
[-23804] = "300/310/325/340",
[-25072] = "300/310/325/340",
[-25073] = "300/310/325/340",
[-25074] = "300/310/325/340",
[-25078] = "300/310/325/340",
[-25079] = "300/310/325/340",
[-25080] = "300/310/325/340",
[-25081] = "300/310/325/340",
[-25082] = "300/310/325/340",
[-25083] = "300/310/325/340",
[-25084] = "300/310/325/340",
[-25086] = "300/310/325/340",
[-25124] = "45/55/65/75",
[-25125] = "150/160/170/180",
[-25126] = "200/210/220/230",
[-25127] = "250/260/270/280",
[-25128] = "275/285/295/305",
[-25129] = "300/310/320/330",
[-25130] = "300/310/320/330",
[-27837] = "290/305/322/340",
[-27899] = "305/315/330/345",
[-27905] = "315/325/340/355",
[-27906] = "320/330/345/360",
[-27911] = "325/335/350/365",
[-27913] = "335/345/360/375",
[-27914] = "350/370/375/380",
[-27917] = "360/370/385/400",
[-27920] = "360/370/377/385",
[-27924] = "360/370/377/385",
[-27926] = "370/380/385/390",
[-27927] = "375/380/385/390",
[-27944] = "310/320/335/350",
[-27945] = "325/335/350/365",
[-27946] = "340/350/365/380",
[-27947] = "360/370/377/385",
[-27948] = "305/315/330/345",
[-27950] = "320/330/345/360",
[-27951] = "340/350/365/380",
[-27954] = "370/380/385/390",
[-27957] = "315/325/340/355",
[-27958] = "350/360/370/380",
[-27960] = "345/355/367/380",
[-27961] = "310/320/335/350",
[-27962] = "330/340/355/370",
[-27967] = "340/350/365/380",
[-27968] = "340/350/365/380",
[-27971] = "350/370/375/380",
[-27972] = "350/370/375/380",
[-27975] = "350/370/375/380",
[-27977] = "360/370/377/385",
[-27981] = "375/390/390/390",
[-27982] = "375/380/385/390",
[-27984] = "375/380/385/390",
[-28003] = "360/370/377/385",
[-28004] = "360/370/377/385",
[-28016] = "310/310/320/330",
[-28019] = "340/340/350/360",
[-28022] = "335/335/335/335",
[-28027] = "325/325/330/335",
[-28028] = "350/370/375/380",
[-32664] = "300/310/325/340",
[-32665] = "350/370/375/380",
[-32667] = "375/375/377/385",
[-33990] = "320/330/345/360",
[-33991] = "300/310/325/340",
[-33992] = "345/355/367/380",
[-33993] = "305/315/330/345",
[-33994] = "360/370/377/385",
[-33995] = "340/350/365/380",
[-33996] = "310/320/335/350",
[-33997] = "360/370/377/385",
[-33999] = "350/370/375/380",
[-34001] = "305/315/330/345",
[-34002] = "300/310/325/340",
[-34003] = "325/335/350/365",
[-34004] = "310/320/335/350",
[-34005] = "350/370/375/380",
[-34006] = "350/370/375/380",
[-34007] = "360/370/377/385",
[-34008] = "360/370/377/385",
[-34009] = "325/335/350/365",
[-34010] = "350/370/375/380",
[-42613] = "300/300/300/305",
[-42615] = "335/335/335/335",
[-42620] = "350/360/367/375",
[-42974] = "375/380/385/390",
[-44383] = "330/340/355/370",
[-44483] = "400/415/425/435",
[-44484] = "405/415/425/435",
[-44488] = "410/420/430/440",
[-44489] = "420/430/440/450",
[-44492] = "395/405/415/425",
[-44494] = "400/415/425/435",
[-44500] = "395/405/415/425",
[-44506] = "375/375/380/390",
[-44508] = "410/420/430/440",
[-44509] = "420/430/440/450",
[-44510] = "410/420/430/440",
[-44513] = "395/405/415/425",
[-44524] = "425/435/445/455",
[-44528] = "385/385/390/400",
[-44529] = "415/425/435/445",
[-44555] = "375/385/392/400",
[-44556] = "400/415/425/435",
[-44575] = "430/440/450/460",
[-44576] = "425/435/445/455",
[-44582] = "395/395/402/410",
[-44584] = "405/415/425/435",
[-44588] = "410/435/445/455",
[-44589] = "415/425/435/445",
[-44590] = "400/415/425/435",
[-44591] = "435/445/455/465",
[-44592] = "360/370/380/390",
[-44593] = "420/430/440/450",
[-44595] = "430/440/450/460",
[-44596] = "400/415/425/435",
[-44598] = "415/425/435/445",
[-44616] = "400/410/420/430",
[-44621] = "430/440/450/460",
[-44623] = "370/380/390/400",
[-44625] = "435/445/455/465",
[-44629] = "395/405/415/425",
[-44630] = "390/400/410/420",
[-44631] = "440/450/460/470",
[-44633] = "410/420/430/440",
[-44635] = "395/405/415/425",
[-44636] = "400/400/407/415",
[-44645] = "400/400/407/415",
[-45765] = "375/375/375/375",
[-46578] = "350/350/357/365",
[-46594] = "360/370/385/400",
[-47051] = "375/380/385/390",
[-47672] = "430/440/450/460",
[-47766] = "400/410/420/430",
[-47898] = "430/440/450/460",
[-47899] = "440/450/460/470",
[-47900] = "425/435/445/455",
[-47901] = "440/450/460/470",
[-59619] = "440/450/460/470",
[-59621] = "440/450/460/470",
[-59625] = "440/450/460/470",
[-59636] = "400/400/407/415",
[-60606] = "375/385/395/405",
[-60609] = "350/360/370/380",
[-60616] = "360/370/380/390",
[-60619] = "425/435/445/455",
[-60621] = "380/390/400/410",
[-60623] = "385/395/405/415",
[-60653] = "395/405/415/425",
[-60663] = "420/430/440/450",
[-60668] = "425/435/445/455",
[-60691] = "430/440/450/460",
[-60692] = "440/450/460/470",
[-60707] = "435/445/455/465",
[-60714] = "435/445/455/465",
[-60763] = "440/450/460/470",
[-60767] = "440/450/460/470",
[-62256] = "450/460/470/480",
[-62948] = "450/455/460/465",
[-62959] = "385/395/405/415",
[-63746] = "225/245/265/285",
[-64441] = "450/455/460/465",
[-64579] = "450/455/460/465",
[-69412] = "445/445/447/450",
[-71692] = "375/385/392/400",
		
-- https://wotlk.wowhead.com/engineering#recipes
-- skipping spellID: 30343 - Blue Smoke Flare
-- skipping spellID: 30549 - Critter Enlarger
-- skipping spellID: 67790 - Dimensional Folder: K3
-- skipping spellID: 12904 - Gnomish Ham Radio
-- skipping spellID: 30573 - Gnomish Tonk Controller
-- skipping spellID: 12720 - Goblin "Boom" Box
-- skipping spellID: 12722 - Goblin Radio
-- skipping spellID: 30561 - Goblin Tonk Controller
-- skipping spellID: 12900 - Mobile Alarm
-- skipping spellID: 30342 - Red Smoke Flare
-- number recipes: 296
[-54736] = "390/390/392/395",
[-54793] = "380/380/382/385",
[-54998] = "400/400/402/405",
[-54999] = "400/400/402/405",
[-55002] = "380/380/382/385",
[-55016] = "405/405/405/410",
[-63765] = "380/380/382/385",
[-63770] = "400/400/402/405",
[-67839] = "410/410/415/420",
[4357] = "1/20/30/40",
[4358] = "1/30/45/60",
[4359] = "30/45/52/60",
[4360] = "30/60/75/90",
[4361] = "50/80/95/110",
[4362] = "50/80/95/110",
[4363] = "65/95/110/125",
[4364] = "75/85/90/95",
[4365] = "75/90/97/105",
[4366] = "85/115/130/145",
[4367] = "100/130/145/160",
[4368] = "100/130/145/160",
[4369] = "105/130/142/155",
[4370] = "105/105/130/155",
[4371] = "105/105/130/155",
[4372] = "120/145/157/170",
[4373] = "120/145/157/170",
[4374] = "120/120/145/170",
[4375] = "125/125/150/175",
[4376] = "125/125/150/175",
[4377] = "125/125/135/145",
[4378] = "125/125/135/145",
[4379] = "130/155/167/180",
[4380] = "140/140/165/190",
[4381] = "140/165/177/190",
[4382] = "145/145/170/195",
[4383] = "145/170/182/195",
[4384] = "150/175/187/200",
[4385] = "150/175/187/200",
[4386] = "155/175/185/195",
[4387] = "160/160/170/180",
[4388] = "160/180/190/200",
[4389] = "170/170/190/210",
[4390] = "175/175/195/215",
[4391] = "175/175/195/215",
[4392] = "185/185/205/225",
[4393] = "185/205/215/225",
[4394] = "190/190/210/230",
[4395] = "195/215/225/235",
[4396] = "200/220/230/240",
[4397] = "200/220/230/240",
[4398] = "200/200/220/240",
[4401] = "75/105/120/135",
[4403] = "165/185/195/205",
[4404] = "90/110/125/140",
[4405] = "60/90/105/120",
[4406] = "110/135/147/160",
[4407] = "180/200/210/220",
[4852] = "185/185/205/225",
[5507] = "135/160/172/185",
[6219] = "50/70/80/90",
[6533] = "150/150/160/170",
[6712] = "100/115/122/130",
[6714] = "100/115/122/130",
[7148] = "165/165/180/200",
[7189] = "225/245/255/265",
[7191] = "275/275/280/285",
[7506] = "125/150/162/175",
[8067] = "1/30/45/60",
[8068] = "75/85/90/95",
[8069] = "125/125/135/145",
[9312] = "150/150/162/175",
[9313] = "150/150/162/175",
[9318] = "150/150/162/175",
[10498] = "175/175/195/215",
[10499] = "175/195/205/215",
[10500] = "205/225/235/245",
[10501] = "220/240/250/260",
[10502] = "225/245/255/265",
[10503] = "230/250/260/270",
[10504] = "245/265/275/285",
[10505] = "175/175/185/195",
[10506] = "230/250/260/270",
[10507] = "175/175/185/195",
[10508] = "205/225/235/245",
[10510] = "220/240/250/260",
[10512] = "210/210/230/250",
[10513] = "245/245/265/285",
[10514] = "215/215/235/255",
[10518] = "225/245/255/265",
[10542] = "205/225/235/245",
[10543] = "205/225/235/245",
[10545] = "210/230/240/250",
[10546] = "210/230/240/250",
[10548] = "240/260/270/280",
[10558] = "150/150/170/190",
[10559] = "195/195/215/235",
[10560] = "200/200/220/240",
[10561] = "215/215/235/255",
[10562] = "235/235/255/275",
[10576] = "250/270/280/290",
[10577] = {[12716] = "205/225/235/245", [13240] = "205/205/205/205"},
[10586] = "235/235/255/275",
[10587] = "230/230/250/270",
[10588] = "245/265/275/285",
[10644] = "205/205/205/205",
[10645] = "240/260/270/280",
[10646] = "205/205/225/245",
[10713] = "205/205/205/205",
[10716] = "205/225/235/245",
[10720] = "210/230/240/250",
[10721] = "215/235/245/255",
[10724] = "225/245/255/265",
[10725] = "230/250/260/270",
[10726] = "235/255/265/275",
[10727] = "240/260/270/280",
[11590] = "200/200/220/240",
[11825] = "205/205/205/205",
[11826] = "205/205/205/205",
[15846] = "250/270/280/290",
[15992] = "250/250/255/260",
[15993] = "260/280/290/300",
[15994] = "260/280/290/300",
[15995] = "260/280/290/300",
[15996] = "265/285/295/305",
[15997] = "285/295/300/305",
[15999] = "270/290/300/310",
[16000] = "275/295/305/315",
[16004] = "275/295/305/315",
[16005] = "285/305/315/325",
[16006] = "285/305/315/325",
[16007] = "300/320/330/340",
[16008] = "290/310/320/330",
[16009] = "290/310/320/330",
[16022] = "300/320/330/340",
[16023] = "275/295/305/315",
[16040] = "300/320/330/340",
[17716] = "190/190/210/230",
[18168] = "300/320/330/340",
[18232] = "300/320/330/340",
[18282] = "300/320/330/340",
[18283] = "300/320/330/340",
[18587] = "265/285/295/305",
[18588] = "200/200/210/220",
[18594] = "275/275/285/295",
[18631] = "260/270/275/280",
[18634] = "260/280/290/300",
[18637] = "275/285/290/295",
[18638] = "290/310/320/330",
[18639] = "300/320/330/340",
[18641] = "250/250/260/270",
[18645] = "265/275/280/285",
[18660] = "260/260/265/270",
[18984] = "285/285/295/305",
[18986] = "285/285/295/305",
[19026] = "250/250/260/270",
[19998] = "300/320/330/340",
[19999] = "300/320/330/340",
[20475] = "335/335/345/355",
[21277] = "250/320/330/340",
[21557] = "125/125/137/150",
[21558] = "125/125/137/150",
[21559] = "125/125/137/150",
[21569] = "225/245/255/265",
[21570] = "275/295/305/315",
[21571] = "225/225/237/250",
[21574] = "225/225/237/250",
[21576] = "225/225/237/250",
[21589] = "175/175/187/200",
[21590] = "175/175/187/200",
[21592] = "175/175/187/200",
[21714] = "275/275/280/285",
[21716] = "275/275/280/285",
[21718] = "275/275/280/285",
[22728] = "275/275/280/285",
[23736] = "300/320/330/340",
[23737] = "325/335/345/355",
[23742] = "320/330/340/350",
[23746] = "350/360/370/380",
[23747] = "360/370/380/390",
[23748] = "375/385/395/405",
[23758] = "340/350/360/370",
[23761] = "340/350/360/370",
[23762] = "350/360/370/380",
[23763] = "360/370/380/390",
[23764] = "335/345/355/365",
[23765] = "360/370/380/390",
[23766] = "375/385/395/405",
[23767] = "325/335/345/355",
[23768] = "335/335/345/355",
[23771] = "335/335/345/355",
[23772] = "310/310/320/330",
[23774] = "325/325/335/345",
[23775] = "405/425/432/440",
[23781] = "300/300/310/320",
[23782] = "300/300/310/320",
[23783] = "300/300/305/310",
[23784] = "325/325/330/335",
[23785] = "340/350/360/370",
[23786] = "340/350/360/370",
[23787] = "340/350/360/370",
[23819] = "350/350/355/360",
[23821] = "305/305/315/325",
[23824] = "355/365/375/385",
[23825] = "350/360/370/380",
[23826] = "325/325/335/345",
[23827] = "340/340/350/360",
[23828] = "375/375/385/395",
[23829] = "375/375/385/395",
[23835] = "340/360/370/380",
[23836] = "350/360/370/380",
[23838] = "375/375/385/395",
[23839] = "375/375/385/395",
[23841] = "325/335/345/355",
[25886] = "335/335/345/355",
[30542] = "350/350/360/370",
[30544] = "350/350/360/370",
[32413] = "335/345/355/365",
[32423] = "335/335/340/345",
[32461] = "350/370/380/390",
[32472] = "350/370/380/390",
[32473] = "350/370/380/390",
[32474] = "350/370/380/390",
[32475] = "350/370/380/390",
[32476] = "350/370/380/390",
[32478] = "350/370/380/390",
[32479] = "350/370/380/390",
[32480] = "350/370/380/390",
[32494] = "350/370/380/390",
[32495] = "350/370/380/390",
[32756] = "375/375/392/410",
[33092] = "330/330/340/350",
[33093] = "345/345/355/365",
[34060] = "300/330/340/350",
[34061] = "375/385/390/395",
[34113] = "360/370/380/390",
[34353] = "375/390/410/430",
[34354] = "375/390/410/430",
[34355] = "375/390/410/430",
[34356] = "375/390/410/430",
[34357] = "375/390/410/430",
[34504] = "335/335/345/355",
[34847] = "375/390/410/430",
[35181] = "375/390/410/430",
[35182] = "375/390/410/430",
[35183] = "375/390/410/430",
[35184] = "375/390/410/430",
[35185] = "375/390/410/430",
[35581] = "355/365/375/385",
[37567] = "410/415/420/425",
[39681] = "350/360/370/380",
[39682] = "375/380/385/390",
[39683] = "390/395/400/405",
[39688] = "400/405/410/415",
[39690] = "350/366/375/385",
[40536] = "375/385/390/395",
[40767] = "420/435/440/445",
[40768] = "425/430/432/435",
[40769] = "415/415/417/420",
[40771] = "350/375/382/390",
[40772] = "435/440/445/450",
[40865] = "420/435/440/445",
[40892] = "375/380/385/390",
[40893] = "375/380/385/390",
[40895] = "425/430/435/440",
[41112] = "420/425/432/440",
[41121] = "425/430/435/440",
[41146] = "425/430/432/435",
[41164] = "410/410/412/420",
[41165] = "415/415/417/425",
[41167] = "430/435/445/455",
[41168] = "450/455/460/465",
[41508] = "450/480/485/490",
[42546] = "415/420/425/430",
[42549] = "440/450/455/460",
[42550] = "440/450/455/460",
[42551] = "440/450/455/460",
[42552] = "440/450/455/460",
[42553] = "440/450/455/460",
[42554] = "440/450/455/460",
[42555] = "440/450/455/460",
[42641] = "425/425/430/435",
[44413] = "450/480/485/490",
[44504] = "450/455/460/465",
[44739] = "390/400/407/415",
[44740] = "420/425/432/440",
[44741] = "420/425/432/440",
[44742] = "420/425/432/440",
[44949] = "440/450/455/460",
[44951] = "405/410/415/420",
[45631] = "250/270/280/290",
[47828] = "410/415/420/425",
[48933] = "435/450/455/460",
[49040] = "450/480/485/490",
[52020] = "450/450/450/460",
[52021] = "450/450/450/460",
		
-- https://wotlk.wowhead.com/jewelcrafting#recipes
-- skipping (1) spellID: 32810 - Primal Stone Statue
-- skipping (1) spellID: 25614 - Silver Rose Pendant
-- number recipes: 556
[20816] = "1/20/35/50",
[20817] = "50/70/80/90",
[20818] = "50/80/95/110",
[20820] = "60/90/105/120",
[20821] = "30/60/75/90",
[20823] = "70/100/115/130",
[20826] = "90/120/135/150",
[20827] = "80/110/125/140",
[20828] = "100/130/145/160",
[20830] = "110/140/155/170",
[20831] = "150/180/195/210",
[20832] = "120/150/165/180",
[20833] = "125/155/170/185",
[20906] = "1/30/45/60",
[20907] = "50/80/95/110",
[20909] = "110/140/155/170",
[20950] = "120/150/165/180",
[20954] = "125/155/170/185",
[20955] = "135/165/180/195",
[20958] = "150/180/195/210",
[20959] = "170/200/215/230",
[20960] = "170/200/215/230",
[20961] = "180/210/225/240",
[20963] = "150/170/180/190",
[20964] = "210/235/250/265",
[20966] = "160/190/205/220",
[20967] = "190/220/235/250",
[20969] = "225/250/265/280",
[21748] = "200/225/240/255",
[21752] = "225/235/245/255",
[21753] = "250/275/290/305",
[21754] = "245/270/285/300",
[21755] = "220/245/260/275",
[21756] = "200/225/240/255",
[21758] = "215/240/255/270",
[21760] = "225/250/265/280",
[21763] = "235/260/275/290",
[21764] = "235/260/275/290",
[21765] = "240/265/280/295",
[21766] = "250/275/290/305",
[21767] = "260/280/290/300",
[21768] = "275/285/295/305",
[21769] = "260/280/290/300",
[21774] = "275/285/295/305",
[21775] = "280/290/300/310",
[21777] = "285/295/305/315",
[21778] = "285/295/305/315",
[21779] = "310/320/330/340",
[21780] = "325/335/345/355",
[21784] = "300/310/320/330",
[21789] = "300/310/320/330",
[21790] = "280/290/300/310",
[21791] = "290/300/310/320",
[21792] = "305/315/325/335",
[21793] = "315/325/335/345",
[21931] = "1/30/45/60",
[21932] = "5/35/50/65",
[21933] = "50/80/95/110",
[21934] = "30/60/75/90",
[23094] = "300/300/320/340",
[23095] = "305/305/325/345",
[23096] = "315/315/335/355",
[23097] = "325/325/340/355",
[23098] = "300/300/320/340",
[23099] = "305/305/325/345",
[23100] = "315/315/335/355",
[23101] = "325/325/340/355",
[23103] = "300/300/320/340",
[23104] = "305/305/325/345",
[23105] = "315/315/335/355",
[23106] = "325/325/340/355",
[23108] = "300/300/320/340",
[23109] = "305/305/325/345",
[23110] = "315/315/335/355",
[23111] = "325/325/340/355",
[23113] = "300/300/320/340",
[23114] = "305/305/325/345",
[23115] = "315/315/335/355",
[23116] = "325/325/340/355",
[23118] = "300/300/320/340",
[23119] = "305/305/325/345",
[23120] = "315/315/335/355",
[23121] = "325/325/340/355",
[24027] = "350/350/365/380",
[24028] = "350/350/365/380",
[24029] = "350/350/365/380",
[24030] = "350/350/365/380",
[24031] = "350/350/365/380",
[24032] = "350/350/365/380",
[24033] = "350/350/365/380",
[24035] = "350/350/365/380",
[24036] = "350/350/365/380",
[24037] = "350/350/365/380",
[24039] = "350/350/365/380",
[24047] = "350/350/365/380",
[24048] = "350/350/365/380",
[24050] = "350/350/365/380",
[24051] = "350/350/365/380",
[24052] = "350/350/365/380",
[24053] = "350/350/365/380",
[24054] = "350/350/365/380",
[24055] = "350/350/365/380",
[24056] = "350/350/365/380",
[24057] = "350/350/365/380",
[24058] = "350/350/365/380",
[24059] = "350/350/365/380",
[24060] = "350/350/365/380",
[24061] = "350/350/365/380",
[24062] = "350/350/365/380",
[24065] = "350/350/365/380",
[24066] = "350/350/365/380",
[24067] = "350/350/365/380",
[24074] = "310/320/330/340",
[24075] = "310/320/335/350",
[24076] = "320/330/340/350",
[24077] = "335/345/355/365",
[24078] = "335/345/355/365",
[24079] = "350/360/370/380",
[24080] = "355/365/372/380",
[24082] = "355/365/372/380",
[24085] = "360/370/375/380",
[24086] = "365/370/375/380",
[24087] = "345/355/365/375",
[24088] = "355/365/375/385",
[24089] = "365/375/377/380",
[24092] = "360/370/375/380",
[24093] = "360/370/375/380",
[24095] = "360/370/375/380",
[24097] = "360/370/375/380",
[24098] = "360/370/375/380",
[24106] = "355/365/375/385",
[24110] = "355/365/375/385",
[24114] = "360/370/377/385",
[24116] = "360/370/375/380",
[24117] = "365/375/380/385",
[24121] = "365/375/380/385",
[24122] = "370/375/380/385",
[24123] = "370/375/380/385",
[24124] = "370/375/380/385",
[24125] = "370/375/380/385",
[24126] = "370/375/380/385",
[24127] = "370/375/380/385",
[24128] = "370/375/380/385",
[25438] = "20/50/65/80",
[25439] = "20/50/65/80",
[25498] = "1/30/40/50",
[25880] = "50/70/80/90",
[25881] = "110/120/130/140",
[25882] = "175/175/185/195",
[25883] = "225/225/235/245",
[25890] = "365/375/377/380",
[25893] = "365/375/377/380",
[25894] = "365/375/377/380",
[25895] = "365/375/377/380",
[25896] = "365/375/377/380",
[25897] = "365/375/377/380",
[25898] = "365/375/377/380",
[25899] = "365/375/377/380",
[25901] = "365/375/377/380",
[28290] = "325/325/340/355",
[28595] = "305/305/325/345",
[29157] = "180/190/200/210",
[29158] = "200/210/220/230",
[29159] = "280/290/300/310",
[29160] = "290/300/310/320",
[30419] = "75/105/120/135",
[30420] = "105/135/150/165",
[30421] = "230/255/270/285",
[30422] = "265/285/295/305",
[30804] = "65/95/110/125",
[30825] = "360/370/375/380",
[31079] = "325/325/335/345",
[31154] = "80/110/125/140",
[31398] = "375/375/380/385",
[31399] = "375/375/380/385",
[31860] = "325/325/340/355",
[31861] = "350/350/365/380",
[31862] = "325/325/340/355",
[31863] = "350/350/365/380",
[31864] = "325/325/340/355",
[31865] = "350/350/365/380",
[31866] = "325/325/340/355",
[31867] = "350/350/365/380",
[31868] = "350/350/365/380",
[31869] = "325/325/340/355",
[32193] = "375/375/380/385",
[32194] = "375/375/380/385",
[32195] = "375/375/380/385",
[32196] = "375/375/380/385",
[32197] = "375/375/380/385",
[32198] = "375/375/380/385",
[32199] = "375/375/380/385",
[32200] = "375/375/380/385",
[32201] = "375/375/380/385",
[32202] = "375/375/380/385",
[32203] = "375/375/380/385",
[32204] = "375/375/380/385",
[32205] = "375/375/380/385",
[32206] = "375/375/380/385",
[32207] = "375/375/380/385",
[32208] = "375/375/380/385",
[32209] = "375/375/380/385",
[32210] = "375/375/380/385",
[32211] = "375/375/380/385",
[32212] = "375/375/380/385",
[32213] = "375/375/380/385",
[32214] = "375/375/380/385",
[32215] = "375/375/380/385",
[32216] = "375/375/380/385",
[32217] = "375/375/380/385",
[32218] = "375/375/380/385",
[32219] = "375/375/380/385",
[32220] = "375/375/380/385",
[32221] = "375/375/380/385",
[32222] = "375/375/380/385",
[32223] = "375/375/380/385",
[32224] = "375/375/380/385",
[32225] = "375/375/380/385",
[32226] = "375/375/380/385",
[32409] = "365/375/377/380",
[32410] = "365/375/377/380",
[32508] = "340/340/355/370",
[32772] = "325/335/345/355",
[32774] = "330/340/350/360",
[32776] = "365/375/380/385",
[32833] = "325/325/332/340",
[32836] = "350/350/365/380",
[33131] = "360/365/370/375",
[33133] = "360/365/370/375",
[33134] = "360/365/370/375",
[33135] = "360/365/370/375",
[33140] = "360/365/370/375",
[33143] = "360/365/370/375",
[33144] = "360/365/370/375",
[33782] = "350/350/365/380",
[34220] = "365/375/377/380",
[34358] = "365/375/380/385",
[34359] = "365/375/380/385",
[34360] = "365/375/380/385",
[34361] = "365/375/380/385",
[34362] = "365/375/380/385",
[34363] = "365/375/380/385",
[35315] = "350/350/365/380",
[35316] = "350/350/365/380",
[35318] = "350/350/365/380",
[35501] = "370/375/377/380",
[35503] = "370/375/377/380",
[35693] = "375/375/380/385",
[35694] = "375/375/380/385",
[35700] = "375/375/380/385",
[35702] = "375/375/380/385",
[35703] = "375/375/380/385",
[35707] = "350/350/365/380",
[35758] = "375/375/380/385",
[35759] = "375/375/380/385",
[35760] = "375/375/380/385",
[35761] = "375/375/380/385",
[36766] = "370/390/415/440",
[36767] = "370/390/415/440",
[37503] = "375/375/380/385",
[39900] = "350/375/395/415",
[39905] = "350/375/395/415",
[39906] = "350/375/395/415",
[39907] = "360/375/395/415",
[39908] = "350/375/395/415",
[39909] = "350/375/395/415",
[39910] = "350/375/395/415",
[39911] = "350/375/395/415",
[39912] = "350/375/395/415",
[39914] = "350/375/395/415",
[39915] = "350/375/395/415",
[39916] = "350/375/395/415",
[39917] = "350/375/395/415",
[39918] = "350/375/395/415",
[39919] = "350/375/395/415",
[39920] = "350/375/395/415",
[39927] = "350/375/395/415",
[39932] = "350/375/395/415",
[39933] = "350/375/395/415",
[39934] = "350/375/395/415",
[39935] = "350/375/395/415",
[39936] = "350/375/395/415",
[39937] = "350/375/395/415",
[39938] = "360/375/395/415",
[39939] = "350/375/395/415",
[39940] = "350/375/395/415",
[39941] = "350/375/395/415",
[39942] = "350/375/395/415",
[39943] = "350/375/395/415",
[39944] = "350/375/395/415",
[39945] = "350/375/395/415",
[39946] = "350/375/395/415",
[39947] = "350/375/395/415",
[39948] = "350/375/395/415",
[39949] = "350/375/395/415",
[39950] = "350/375/395/415",
[39951] = "350/375/395/415",
[39952] = "350/375/395/415",
[39953] = "350/375/395/415",
[39954] = "350/375/395/415",
[39955] = "350/375/395/415",
[39956] = "350/375/395/415",
[39957] = "350/375/395/415",
[39958] = "350/375/395/415",
[39959] = "350/375/395/415",
[39960] = "350/375/395/415",
[39961] = "350/375/395/415",
[39962] = "350/375/395/415",
[39963] = "350/375/395/415",
[39964] = "350/375/395/415",
[39965] = "360/375/395/415",
[39966] = "350/375/395/415",
[39967] = "350/375/395/415",
[39968] = "350/375/395/415",
[39974] = "350/375/395/415",
[39975] = "350/375/395/415",
[39976] = "350/375/395/415",
[39977] = "350/375/395/415",
[39978] = "350/375/395/415",
[39979] = "350/375/395/415",
[39980] = "350/375/395/415",
[39981] = "350/375/395/415",
[39982] = "350/375/395/415",
[39983] = "350/375/395/415",
[39984] = "350/375/395/415",
[39985] = "350/375/395/415",
[39986] = "350/375/395/415",
[39988] = "350/375/395/415",
[39989] = "350/375/395/415",
[39990] = "350/375/395/415",
[39991] = "350/375/395/415",
[39992] = "350/375/395/415",
[39996] = "390/410/425/440",
[39997] = "390/410/425/440",
[39998] = "390/410/425/440",
[39999] = "390/410/425/440",
[40000] = "390/410/425/440",
[40001] = "390/410/425/440",
[40002] = "390/410/425/440",
[40003] = "390/410/425/440",
[40008] = "390/410/425/440",
[40009] = "390/410/425/440",
[40010] = "390/410/425/440",
[40011] = "390/410/425/440",
[40012] = "390/410/425/440",
[40013] = "390/410/425/440",
[40014] = "390/410/425/440",
[40015] = "390/410/425/440",
[40016] = "390/410/425/440",
[40017] = "390/410/425/440",
[40022] = "390/410/425/440",
[40023] = "390/410/425/440",
[40024] = "390/410/425/440",
[40025] = "390/410/425/440",
[40026] = "390/410/425/440",
[40027] = "390/410/425/440",
[40028] = "390/410/425/440",
[40029] = "390/410/425/440",
[40030] = "390/410/425/440",
[40031] = "390/410/425/440",
[40032] = "390/410/425/440",
[40033] = "390/410/425/440",
[40034] = "390/410/425/440",
[40037] = "390/410/425/440",
[40038] = "390/410/425/440",
[40039] = "390/410/425/440",
[40040] = "390/410/425/440",
[40041] = "390/410/425/440",
[40043] = "390/410/425/440",
[40044] = "390/410/425/440",
[40045] = "390/410/425/440",
[40046] = "390/410/425/440",
[40047] = "390/410/425/440",
[40048] = "390/410/425/440",
[40049] = "390/410/425/440",
[40050] = "390/410/425/440",
[40051] = "390/410/425/440",
[40052] = "390/410/425/440",
[40053] = "390/410/425/440",
[40054] = "390/410/425/440",
[40055] = "390/410/425/440",
[40056] = "390/410/425/440",
[40057] = "390/410/425/440",
[40058] = "390/410/425/440",
[40059] = "390/410/425/440",
[40085] = "390/410/425/440",
[40086] = "390/410/425/440",
[40088] = "390/410/425/440",
[40089] = "390/410/425/440",
[40090] = "390/410/425/440",
[40091] = "390/410/425/440",
[40092] = "390/410/425/440",
[40094] = "390/410/425/440",
[40095] = "390/410/425/440",
[40096] = "390/410/425/440",
[40098] = "390/410/425/440",
[40099] = "390/410/425/440",
[40100] = "390/410/425/440",
[40101] = "390/410/425/440",
[40102] = "390/410/425/440",
[40103] = "390/410/425/440",
[40104] = "390/410/425/440",
[40105] = "390/410/425/440",
[40106] = "390/410/425/440",
[40111] = "450/450/452/465",
[40112] = "450/450/452/465",
[40113] = "450/450/452/465",
[40114] = "450/450/452/465",
[40115] = "450/450/452/465",
[40116] = "450/450/452/465",
[40117] = "450/450/452/465",
[40118] = "450/450/452/465",
[40119] = "450/450/452/465",
[40120] = "450/450/452/465",
[40121] = "450/450/452/465",
[40122] = "450/450/452/465",
[40123] = "450/450/452/465",
[40124] = "450/450/452/465",
[40125] = "450/450/452/465",
[40126] = "450/450/452/465",
[40127] = "450/450/452/465",
[40128] = "450/450/452/465",
[40129] = "450/450/452/465",
[40130] = "450/450/452/465",
[40131] = "450/450/452/465",
[40132] = "450/450/452/465",
[40133] = "450/450/452/465",
[40134] = "450/450/452/465",
[40135] = "450/450/452/465",
[40136] = "450/450/452/465",
[40137] = "450/450/452/465",
[40138] = "450/450/452/465",
[40139] = "450/450/452/465",
[40140] = "450/450/452/465",
[40141] = "450/450/452/465",
[40142] = "450/450/452/465",
[40143] = "450/450/452/465",
[40144] = "450/450/452/465",
[40145] = "450/450/452/465",
[40146] = "450/450/452/465",
[40147] = "450/450/452/465",
[40148] = "450/450/452/465",
[40149] = "450/450/452/465",
[40150] = "450/450/452/465",
[40151] = "450/450/452/465",
[40152] = "450/450/452/465",
[40153] = "450/450/452/465",
[40154] = "450/450/452/465",
[40155] = "450/450/452/465",
[40156] = "450/450/452/465",
[40157] = "450/450/452/465",
[40158] = "450/450/452/465",
[40159] = "450/450/452/465",
[40160] = "450/450/452/465",
[40161] = "450/450/452/465",
[40162] = "450/450/452/465",
[40163] = "450/450/452/465",
[40164] = "450/450/452/465",
[40165] = "450/450/452/465",
[40166] = "450/450/452/465",
[40167] = "450/450/452/465",
[40168] = "450/450/452/465",
[40169] = "450/450/452/465",
[40170] = "450/450/452/465",
[40171] = "450/450/452/465",
[40172] = "450/450/452/465",
[40173] = "450/450/452/465",
[40174] = "450/450/452/465",
[40175] = "450/450/452/465",
[40176] = "450/450/452/465",
[40177] = "450/450/452/465",
[40178] = "450/450/452/465",
[40179] = "450/450/452/465",
[40180] = "450/450/452/465",
[40181] = "450/450/452/465",
[40182] = "450/450/452/465",
[41285] = "420/440/450/460",
[41307] = "420/440/450/460",
[41333] = "420/440/450/460",
[41335] = "420/440/450/460",
[41339] = "420/440/450/460",
[41367] = "350/360/370/380",
[41375] = "420/440/450/460",
[41376] = "420/440/450/460",
[41377] = "420/440/450/460",
[41378] = "420/440/450/460",
[41379] = "420/440/450/460",
[41380] = "420/440/450/460",
[41381] = "420/440/450/460",
[41382] = "420/440/450/460",
[41385] = "420/440/450/460",
[41389] = "420/440/450/460",
[41395] = "420/440/450/460",
[41396] = "420/440/450/460",
[41397] = "420/440/450/460",
[41398] = "420/440/450/460",
[41400] = "420/440/450/460",
[41401] = "420/440/450/460",
[42142] = "370/390/415/440",
[42143] = "370/390/415/440",
[42144] = "370/390/415/440",
[42145] = "370/390/415/440",
[42146] = "370/390/415/440",
[42148] = "370/390/415/440",
[42149] = "370/390/415/440",
[42150] = "370/390/415/440",
[42151] = "370/390/415/440",
[42152] = "370/390/415/440",
[42153] = "370/390/415/440",
[42154] = "370/390/415/440",
[42155] = "370/390/415/440",
[42156] = "370/390/415/440",
[42157] = "370/390/415/440",
[42158] = "370/390/415/440",
[42336] = "350/380/400/420",
[42337] = "350/380/400/420",
[42338] = "380/400/410/420",
[42339] = "380/400/410/420",
[42340] = "420/440/450/460",
[42341] = "400/430/440/450",
[42395] = "400/430/440/450",
[42413] = "400/430/440/450",
[42418] = "400/430/440/450",
[42420] = "360/370/380/390",
[42421] = "370/380/390/400",
[42642] = "430/450/455/460",
[42643] = "430/450/455/460",
[42644] = "430/450/455/460",
[42645] = "440/450/455/460",
[42646] = "440/450/455/460",
[42647] = "440/450/455/460",
[42701] = "360/380/400/420",
[42702] = "390/410/425/440",
[43244] = "350/380/400/420",
[43245] = "350/380/400/420",
[43246] = "370/390/405/420",
[43247] = "370/390/405/420",
[43248] = "390/410/420/430",
[43249] = "390/410/420/430",
[43250] = "420/440/450/460",
[43251] = "420/440/450/460",
[43252] = "420/440/450/460",
[43253] = "420/440/450/460",
[43482] = "420/440/450/460",
[43498] = "420/440/450/460",
[43582] = "420/440/450/460",
[44063] = "400/430/440/450",
[44943] = "425/445/457/470",
[45054] = "300/310/315/320",
[45627] = "200/210/220/230",
[45808] = "420/440/450/460",
[45809] = "420/440/450/460",
[45812] = "420/440/450/460",
[45813] = "420/440/450/460",
[49110] = "450/450/452/465",
[191061] = "350/350/365/380",
						
-- https://wotlk.wowhead.com/leatherworking#recipes
-- skipping spellID: 55243 - Bracers of Deflection
-- skipping spellID: 10550 - Nightscape Cloak
-- skipping spellID: 19106 - Onyxia Scale Breastplate
-- number recipes: 541
[-57683] = "400/425/430/435",
[-57690] = "400/425/430/435",
[-57691] = "400/425/430/435",
[-57692] = "400/425/430/435",
[-57694] = "400/425/430/435",
[-57696] = "400/425/430/435",
[-57699] = "400/425/430/435",
[-57701] = "400/425/430/435",
[-60583] = "405/405/405/410",
[-60584] = "400/400/400/405",
[2300] = "40/70/85/100",
[2302] = "1/40/55/70",
[2303] = "15/45/60/75",
[2304] = "1/30/45/60",
[2307] = "90/120/135/150",
[2308] = "85/105/120/135",
[2309] = "55/85/100/115",
[2310] = "60/90/105/120",
[2311] = "60/90/105/120",
[2312] = "75/105/120/135",
[2313] = "100/115/122/130",
[2314] = "120/145/157/170",
[2315] = "100/125/137/150",
[2316] = "110/135/147/160",
[2317] = "100/125/137/150",
[2318] = "1/20/30/40",
[2319] = "100/100/105/110",
[3719] = "150/170/180/190",
[4231] = "35/55/65/75",
[4233] = "100/115/122/130",
[4234] = "150/150/155/160",
[4236] = "150/160/165/170",
[4237] = "25/55/70/85",
[4239] = "55/85/100/115",
[4242] = "75/105/120/135",
[4243] = "85/115/130/145",
[4244] = "100/125/137/150",
[4246] = "80/110/125/140",
[4247] = "145/170/182/195",
[4248] = "120/155/167/180",
[4249] = "125/150/162/175",
[4250] = "120/145/157/170",
[4251] = "130/155/167/180",
[4252] = "140/165/177/190",
[4253] = "135/160/172/185",
[4254] = "150/170/180/190",
[4255] = "155/175/185/195",
[4256] = "175/195/205/215",
[4257] = "160/180/190/200",
[4258] = "170/190/200/210",
[4259] = "180/200/210/220",
[4260] = "195/215/225/235",
[4262] = "185/205/215/225",
[4264] = "200/220/230/240",
[4265] = "150/170/180/190",
[4304] = "200/200/202/205",
[4455] = "165/185/195/205",
[4456] = "165/185/195/205",
[5081] = "40/70/85/100",
[5739] = "190/210/220/230",
[5780] = "90/120/135/150",
[5781] = "95/125/140/155",
[5782] = "170/190/200/210",
[5783] = "190/210/220/230",
[5957] = "1/40/55/70",
[5958] = "105/130/142/155",
[5961] = "115/140/152/165",
[5962] = "160/180/190/200",
[5963] = "170/190/200/210",
[5964] = "175/195/205/215",
[5965] = "185/205/215/225",
[5966] = "190/210/220/230",
[6466] = "90/120/135/150",
[6467] = "105/130/142/155",
[6468] = "115/140/152/165",
[6709] = "90/115/130/145",
[7276] = "1/40/55/70",
[7277] = "1/40/55/70",
[7278] = "30/60/75/90",
[7279] = "30/60/75/90",
[7280] = "35/65/80/95",
[7281] = "70/100/115/130",
[7282] = "95/125/140/155",
[7283] = "100/125/137/150",
[7284] = "120/145/157/170",
[7285] = "120/145/157/170",
[7348] = "125/150/162/175",
[7349] = "135/160/172/185",
[7352] = "135/160/172/185",
[7358] = "140/165/177/190",
[7359] = "145/170/182/195",
[7371] = "150/170/180/190",
[7372] = "150/170/180/190",
[7373] = "165/185/195/205",
[7374] = "175/195/205/215",
[7375] = "175/195/205/215",
[7377] = "180/200/210/220",
[7378] = "185/205/215/225",
[7386] = "190/210/220/230",
[7387] = "195/215/225/235",
[7390] = "200/220/230/240",
[7391] = "200/220/230/240",
[8170] = "250/250/250/250",
[8172] = "200/200/200/200",
[8173] = "200/220/230/240",
[8174] = "200/220/230/240",
[8175] = "205/225/235/245",
[8176] = "205/225/235/245",
[8185] = "235/255/265/275",
[8187] = "205/225/235/245",
[8189] = "210/230/240/250",
[8191] = "230/250/260/270",
[8192] = "210/230/240/250",
[8193] = "230/250/260/270",
[8197] = "235/255/265/275",
[8198] = "210/230/240/250",
[8200] = "215/235/245/255",
[8201] = "220/240/250/260",
[8202] = "240/260/270/280",
[8203] = "220/240/250/260",
[8204] = "225/245/255/265",
[8205] = "220/240/250/260",
[8206] = "245/265/275/285",
[8207] = "240/260/270/280",
[8208] = "250/270/280/290",
[8209] = "235/255/265/275",
[8210] = "220/240/250/260",
[8211] = "225/245/255/265",
[8212] = "250/270/280/290",
[8213] = "245/265/275/285",
[8214] = "225/245/255/265",
[8215] = "250/270/280/290",
[8216] = "240/260/270/280",
[8217] = "225/245/255/265",
[8218] = "225/245/255/265",
[8345] = "225/245/255/265",
[8346] = "230/250/260/270",
[8347] = "225/245/255/265",
[8348] = "250/270/280/290",
[8349] = "250/270/280/290",
[8367] = "255/275/285/295",
[15045] = "260/280/290/300",
[15046] = "270/290/300/310",
[15047] = "300/320/330/340",
[15048] = "285/305/315/325",
[15049] = "295/315/325/335",
[15050] = "290/310/320/330",
[15051] = "300/320/330/340",
[15052] = "300/320/330/340",
[15053] = "285/305/315/325",
[15054] = "270/290/300/310",
[15055] = "300/320/330/340",
[15056] = "285/305/315/325",
[15057] = "275/295/305/315",
[15058] = "295/315/325/335",
[15059] = "300/320/330/340",
[15060] = "285/305/315/325",
[15061] = "270/290/300/310",
[15062] = "300/320/330/340",
[15063] = "290/310/320/330",
[15064] = "275/295/305/315",
[15065] = "285/305/315/325",
[15066] = "290/310/320/330",
[15067] = "270/290/300/310",
[15068] = "300/320/330/340",
[15069] = "285/305/315/325",
[15070] = "295/315/325/335",
[15071] = "275/295/305/315",
[15072] = "280/300/310/320",
[15073] = "275/295/305/315",
[15074] = "265/285/295/305",
[15075] = "290/310/320/330",
[15076] = "265/285/295/305",
[15077] = "255/275/285/295",
[15078] = "275/295/305/315",
[15079] = "285/305/315/325",
[15080] = "295/315/325/335",
[15081] = "300/320/330/340",
[15082] = "280/300/310/320",
[15083] = "260/280/290/300",
[15084] = "265/285/295/305",
[15085] = "300/320/330/340",
[15086] = "280/300/310/320",
[15087] = "290/310/320/330",
[15088] = "300/320/330/340",
[15090] = "300/320/330/340",
[15091] = "270/290/300/310",
[15092] = "275/295/305/315",
[15093] = "280/300/310/320",
[15094] = "290/310/320/330",
[15095] = "300/320/330/340",
[15096] = "300/320/330/340",
[15138] = "300/320/330/340",
[15407] = "250/250/255/260",
[15564] = "250/255/265/275",
[16982] = "295/315/325/335",
[16983] = "300/320/330/340",
[16984] = "300/320/330/340",
[17721] = "190/210/220/230",
[18238] = "200/210/220/230",
[18251] = "300/320/330/340",
[18258] = "285/285/290/295",
[18504] = "300/320/330/340",
[18506] = "300/320/330/340",
[18508] = "300/320/330/340",
[18509] = "300/320/330/340",
[18510] = "300/320/330/340",
[18511] = "300/320/330/340",
[18662] = "150/150/155/160",
[18948] = "155/175/185/195",
[19044] = "290/310/320/330",
[19049] = "300/320/330/340",
[19052] = "290/310/320/330",
[19058] = "300/320/330/340",
[19149] = "300/320/330/340",
[19157] = "300/320/330/340",
[19162] = "300/320/330/340",
[19163] = "300/320/330/340",
[19685] = "300/320/330/340",
[19686] = "300/320/330/340",
[19687] = "300/320/330/340",
[19688] = "300/320/330/340",
[19689] = "300/320/330/340",
[20295] = "300/320/330/340",
[20296] = "280/300/310/320",
[20380] = "300/320/330/340",
[20476] = "300/320/330/340",
[20477] = "300/320/330/340",
[20478] = "300/320/330/340",
[20479] = "300/320/330/340",
[20480] = "300/320/330/340",
[20481] = "300/320/330/340",
[20575] = "100/125/137/150",
[21278] = "300/320/330/340",
[21887] = "300/300/305/310",
[22661] = "300/320/330/340",
[22662] = "300/320/330/340",
[22663] = "300/320/330/340",
[22664] = "300/320/330/340",
[22665] = "300/320/330/340",
[22666] = "300/320/330/340",
[22759] = "300/320/330/340",
[22760] = "300/320/330/340",
[22761] = "300/320/330/340",
[23793] = "325/325/330/335",
[25650] = "300/310/325/340",
[25651] = "325/335/340/345",
[25652] = "325/335/340/345",
[25653] = "350/360/370/380",
[25654] = "300/310/320/330",
[25655] = "310/320/330/340",
[25656] = "320/330/340/350",
[25657] = "335/345/355/365",
[25659] = "335/345/355/365",
[25660] = "325/335/345/355",
[25661] = "310/320/330/340",
[25662] = "300/310/320/330",
[25668] = "320/330/340/350",
[25669] = "300/310/320/330",
[25670] = "315/325/335/345",
[25671] = "330/340/350/360",
[25673] = "300/310/320/330",
[25674] = "310/320/330/340",
[25675] = "320/330/340/350",
[25676] = "330/340/350/360",
[25679] = "300/300/305/310",
[25680] = "350/360/370/380",
[25681] = "350/360/370/380",
[25682] = "350/360/370/380",
[25683] = "350/360/370/380",
[25685] = "340/350/360/370",
[25686] = "350/360/370/380",
[25687] = "350/360/370/380",
[25689] = "360/370/380/390",
[25690] = "355/365/375/385",
[25691] = "355/365/375/385",
[25692] = "340/350/360/370",
[25693] = "350/360/370/380",
[25694] = "340/350/360/370",
[25695] = "350/360/370/380",
[25696] = "360/370/380/390",
[25697] = "360/370/380/390",
[29483] = "340/350/355/360",
[29485] = "340/350/355/360",
[29486] = "340/350/355/360",
[29487] = "340/350/355/360",
[29488] = "340/350/355/360",
[29489] = "350/360/370/380",
[29490] = "350/360/370/380",
[29491] = "350/360/370/380",
[29492] = "350/360/370/380",
[29493] = "350/360/370/380",
[29494] = "350/360/370/380",
[29495] = "350/360/370/380",
[29496] = "350/360/370/380",
[29497] = "350/360/370/380",
[29498] = "350/360/370/380",
[29499] = "350/360/370/380",
[29500] = "350/360/370/380",
[29502] = "365/375/385/395",
[29503] = "365/375/385/395",
[29504] = "365/375/385/395",
[29505] = "365/375/385/395",
[29506] = "365/375/385/395",
[29507] = "365/375/385/395",
[29508] = "365/375/385/395",
[29509] = "365/375/385/395",
[29510] = "365/375/385/395",
[29511] = "365/375/385/395",
[29512] = "365/375/385/395",
[29514] = "365/375/385/395",
[29515] = "375/385/395/405",
[29516] = "375/385/395/405",
[29517] = "375/385/395/405",
[29519] = "375/385/395/405",
[29520] = "375/385/395/405",
[29521] = "375/385/395/405",
[29522] = "375/385/395/405",
[29523] = "375/385/395/405",
[29524] = "375/385/395/405",
[29525] = "375/385/395/405",
[29526] = "375/385/395/405",
[29527] = "375/385/395/405",
[29528] = "340/340/347/355",
[29529] = "365/365/372/380",
[29530] = "345/345/352/360",
[29531] = "350/350/357/365",
[29532] = "370/370/377/385",
[29533] = "335/335/345/355",
[29534] = "335/335/345/355",
[29535] = "365/365/375/385",
[29536] = "365/365/375/385",
[29540] = "325/335/340/345",
[29964] = "260/280/290/300",
[29970] = "260/280/290/300",
[29971] = "260/280/290/300",
[29973] = "330/350/360/370",
[29974] = "330/350/360/370",
[29975] = "330/350/360/370",
[30039] = "375/385/395/405",
[30040] = "375/385/395/405",
[30041] = "375/385/395/405",
[30042] = "375/385/395/405",
[30043] = "375/385/395/405",
[30044] = "375/385/395/405",
[30045] = "375/385/395/405",
[30046] = "375/385/395/405",
[32393] = "375/385/395/405",
[32394] = "375/385/395/405",
[32395] = "375/385/395/405",
[32396] = "375/385/395/405",
[32397] = "375/385/395/405",
[32398] = "375/385/395/405",
[32399] = "375/385/395/405",
[32400] = "375/385/395/405",
[32574] = "375/385/395/405",
[32575] = "375/385/395/405",
[32577] = "375/385/395/405",
[32579] = "375/385/395/405",
[32580] = "375/385/395/405",
[32581] = "375/385/395/405",
[32582] = "375/385/395/405",
[32583] = "375/385/395/405",
[33122] = "360/370/380/390",
[33204] = "365/375/385/395",
[33568] = "350/350/362/375",
[34086] = "285/285/285/285",
[34099] = "315/325/335/345",
[34100] = "315/325/335/345",
[34105] = "350/360/370/380",
[34106] = "350/360/370/380",
[34207] = "350/355/360/365",
[34330] = "350/355/360/365",
[34369] = "365/375/392/410",
[34370] = "365/375/392/410",
[34371] = "365/375/392/410",
[34372] = "365/375/392/410",
[34373] = "365/375/392/410",
[34374] = "365/375/392/410",
[34375] = "365/375/392/410",
[34376] = "365/375/392/410",
[34482] = "300/310/320/330",
[34490] = "350/370/380/390",
[38347] = "415/420/422/425",
[38371] = "405/410/415/420",
[38372] = "400/405/410/415",
[38373] = "425/435/440/445",
[38374] = "425/435/440/445",
[38375] = "350/375/380/385",
[38376] = "395/400/402/405",
[38399] = "415/420/422/425",
[38400] = "370/385/395/405",
[38401] = "375/390/400/410",
[38402] = "380/395/405/415",
[38403] = "375/390/400/410",
[38404] = "370/385/395/405",
[38405] = "380/395/405/415",
[38406] = "380/380/387/395",
[38407] = "375/390/400/410",
[38408] = "375/390/400/410",
[38409] = "370/385/395/405",
[38410] = "370/385/395/405",
[38411] = "380/395/405/415",
[38412] = "370/385/395/405",
[38413] = "380/395/405/415",
[38414] = "375/390/400/410",
[38415] = "380/395/405/415",
[38416] = "370/385/395/405",
[38417] = "380/395/405/415",
[38418] = "375/390/400/410",
[38419] = "380/395/405/415",
[38420] = "375/390/400/410",
[38421] = "370/385/395/405",
[38422] = "370/385/395/405",
[38424] = "375/390/400/410",
[38425] = "390/390/395/405",
[38433] = "385/400/410/420",
[38434] = "385/400/410/420",
[38435] = "385/400/410/420",
[38436] = "385/400/410/420",
[38437] = "385/400/410/420",
[38438] = "385/400/410/420",
[38439] = "385/400/410/420",
[38440] = "385/400/410/420",
[38441] = "380/390/400/410",
[38590] = "400/415/425/435",
[38591] = "395/410/420/430",
[38592] = "395/410/420/430",
[41238] = "395/405/415/425",
[42731] = "425/430/435/440",
[43129] = "425/430/435/440",
[43130] = "420/425/430/435",
[43131] = "420/425/430/435",
[43132] = "425/430/435/440",
[43133] = "420/425/430/435",
[43255] = "420/425/430/435",
[43256] = "420/425/430/435",
[43257] = "425/430/435/440",
[43258] = "420/425/430/435",
[43260] = "420/425/430/435",
[43261] = "420/425/430/435",
[43262] = "420/425/430/435",
[43263] = "420/425/430/435",
[43264] = "420/425/430/435",
[43265] = "425/430/435/440",
[43266] = "425/430/435/440",
[43271] = "425/430/435/440",
[43273] = "425/430/435/440",
[43433] = "420/425/430/435",
[43434] = "420/425/430/435",
[43435] = "420/425/430/435",
[43436] = "425/430/435/440",
[43437] = "425/430/435/440",
[43438] = "425/430/435/440",
[43439] = "425/430/435/440",
[43442] = "425/430/435/440",
[43443] = "425/430/435/440",
[43444] = "420/425/430/435",
[43445] = "420/425/430/435",
[43446] = "425/430/435/440",
[43447] = "420/425/430/435",
[43448] = "425/430/435/440",
[43449] = "420/425/430/435",
[43450] = "425/430/435/440",
[43451] = "425/430/435/440",
[43452] = "420/425/430/435",
[43453] = "420/425/430/435",
[43454] = "425/430/435/440",
[43455] = "420/425/430/435",
[43456] = "425/430/435/440",
[43457] = "420/425/430/435",
[43458] = "440/450/455/460",
[43459] = "440/450/455/460",
[43461] = "440/450/455/460",
[43469] = "440/450/455/460",
[43481] = "440/450/455/460",
[43484] = "440/450/455/460",
[43495] = "440/450/455/460",
[43502] = "440/450/455/460",
[43565] = "440/450/455/460",
[43566] = "440/450/455/460",
[43590] = "425/435/445/455",
[43591] = "420/430/440/450",
[43592] = "420/430/440/450",
[43593] = "425/435/445/455",
[43594] = "420/430/440/450",
[43595] = "420/430/440/450",
[44436] = "395/410/420/430",
[44437] = "395/410/420/430",
[44438] = "400/415/425/435",
[44440] = "395/410/420/430",
[44441] = "395/410/420/430",
[44442] = "400/415/425/435",
[44443] = "395/410/420/430",
[44444] = "395/410/420/430",
[44445] = "400/415/425/435",
[44446] = "415/420/422/425",
[44447] = "415/420/422/425",
[44448] = "415/420/422/425",
[44930] = "440/450/455/460",
[44931] = "440/450/455/460",
[44963] = "425/435/440/445",
[45553] = "450/455/465/475",
[45554] = "450/455/465/475",
[45555] = "450/455/465/475",
[45556] = "450/455/465/475",
[45562] = "450/455/465/475",
[45563] = "450/455/465/475",
[45564] = "450/455/465/475",
[45565] = "450/455/465/475",
[47576] = "450/460/467/475",
[47577] = "450/460/467/475",
[47579] = "450/460/467/475",
[47580] = "450/460/467/475",
[47581] = "450/460/467/475",
[47582] = "450/460/467/475",
[47583] = "450/460/467/475",
[47584] = "450/460/467/475",
[47595] = "450/460/467/475",
[47596] = "450/460/467/475",
[47597] = "450/460/467/475",
[47598] = "450/460/467/475",
[47599] = "450/460/467/475",
[47600] = "450/460/467/475",
[47601] = "450/460/467/475",
[47602] = "450/460/467/475",
[49633] = "450/450/455/470",
[49634] = "450/450/455/470",
[49894] = "450/475/487/500",
[49895] = "450/475/487/500",
[49896] = "450/475/487/500",
[49897] = "450/475/487/500",
[49898] = "450/475/487/500",
[49899] = "450/475/487/500",
[49900] = "450/475/487/500",
[49901] = "450/475/487/500",
[185848] = "365/365/372/380",
[185849] = "370/370/377/385",
[185850] = "350/350/357/365",
[185851] = "345/345/352/360",
[185852] = "340/340/347/355",
		
-- https://wotlk.wowhead.com/mining#recipes
-- number recipes: 26
[2840] = "1/25/47/70",
[2841] = "65/65/90/115",
[2842] = "75/115/122/130",
[3575] = "125/130/145/160",
[3576] = "65/65/70/75",
[3577] = "155/170/177/185",
[3859] = "165/165/165/165",
[3860] = "175/175/202/230",
[6037] = "230/250/270/290",
[11371] = "300/300/305/310",
[12359] = "230/250/270/290",
[12655] = "250/250/255/260",
[17771] = "300/350/362/375",
[22573] = "300/300/300/300",
[22574] = "300/300/300/300",
[23445] = "275/275/300/325",
[23446] = "325/325/332/340",
[23447] = "350/350/357/365",
[23448] = "350/350/357/375",
[23449] = "375/375/375/375",
[23573] = "375/375/375/375",
[35128] = "375/375/375/375",
[36913] = "400/400/400/400",
[36916] = "350/350/362/375",
[37663] = "450/450/450/450",
[41163] = "450/450/450/450",
		
-- https://wotlk.wowhead.com/tailoring#recipes
-- skipping spellID: 8778 - Boots of Darkness
-- skipping spellID: 7636 - Green Woolen Robe
-- skipping spellID: 31461 - Heavy Netherweave Net
-- skipping spellID: 36670 - Lifeblood Belt
-- skipping spellID: 36672 - Lifeblood Bracers
-- skipping spellID: 36669 - Lifeblood Leggings
-- skipping spellID: 36667 - Netherflame Belt
-- skipping spellID: 36668 - Netherflame Boots
-- skipping spellID: 36665 - Netherflame Robe
-- skipping spellID: 12090 - Stormcloth Boots
-- skipping spellID: 12063 - Stormcloth Gloves
-- skipping spellID: 12083 - Stormcloth Headband
-- skipping spellID: 12062 - Stormcloth Pants
-- skipping spellID: 12087 - Stormcloth Shoulders
-- skipping spellID: 12068 - Stormcloth Vest
-- number recipes: 414
[-55642] = "420/420/420/420",
[-55769] = "420/420/420/420",
[-55777] = "420/420/420/420",
[-56034] = "405/405/405/405",
[-56039] = "405/405/405/405",
[2568] = "10/45/57/70",
[2569] = "65/90/107/125",
[2570] = "1/35/47/60",
[2572] = "40/65/82/100",
[2575] = "40/65/82/100",
[2576] = "1/35/47/60",
[2577] = "40/65/82/100",
[2578] = "70/95/112/130",
[2579] = "70/95/112/130",
[2580] = "60/85/102/120",
[2582] = "85/110/127/145",
[2583] = "95/120/137/155",
[2584] = "75/100/117/135",
[2585] = "105/130/147/165",
[2587] = "100/110/120/130",
[2996] = "1/25/37/50",
[2997] = "75/90/97/105",
[4238] = "45/70/87/105",
[4240] = "80/105/122/140",
[4241] = "95/120/137/155",
[4245] = "150/170/185/200",
[4305] = "125/135/140/145",
[4307] = "35/60/77/95",
[4308] = "60/85/102/120",
[4309] = "70/95/112/130",
[4310] = "85/110/127/145",
[4311] = "100/125/142/160",
[4312] = "80/105/122/140",
[4313] = "95/120/137/155",
[4314] = "110/135/152/170",
[4315] = "120/145/162/180",
[4316] = "110/135/152/170",
[4317] = "125/150/167/185",
[4318] = "130/150/165/180",
[4319] = "145/165/180/195",
[4320] = "125/150/167/185",
[4321] = "140/160/175/190",
[4322] = "165/185/200/215",
[4323] = "170/190/205/220",
[4324] = "150/170/185/200",
[4325] = "175/195/210/225",
[4326] = "185/205/220/235",
[4327] = "200/220/235/250",
[4328] = "180/200/215/230",
[4329] = "200/220/235/250",
[4330] = "110/135/152/170",
[4331] = "125/150/167/185",
[4332] = "135/145/150/155",
[4333] = "155/165/170/175",
[4334] = "170/180/185/190",
[4335] = "185/195/200/205",
[4336] = "200/210/215/220",
[4339] = "175/180/182/185",
[4343] = "30/55/72/90",
[4344] = "1/35/47/60",
[5542] = "90/115/132/150",
[5762] = "70/95/112/130",
[5763] = "115/140/157/175",
[5764] = "175/195/210/225",
[5765] = "185/205/220/235",
[5766] = "135/155/170/185",
[5770] = "150/170/185/200",
[6238] = "30/55/72/90",
[6239] = "55/80/97/115",
[6240] = "55/80/97/115",
[6241] = "30/55/72/90",
[6242] = "70/95/112/130",
[6263] = "100/125/142/160",
[6264] = "115/140/157/175",
[6384] = "120/145/162/180",
[6385] = "120/145/162/180",
[6786] = "40/65/82/100",
[6787] = "110/135/152/170",
[6795] = "160/170/175/180",
[6796] = "175/185/190/195",
[6836] = "250/255/270/285",
[7026] = "15/50/67/85",
[7046] = "140/160/175/190",
[7047] = "145/165/180/195",
[7048] = "145/155/160/165",
[7049] = "150/170/185/200",
[7050] = "160/170/175/180",
[7051] = "170/190/205/220",
[7052] = "175/195/210/225",
[7053] = "175/195/210/225",
[7054] = "190/210/225/240",
[7055] = "175/195/210/225",
[7056] = "180/200/215/230",
[7057] = "180/200/215/230",
[7058] = "185/205/215/225",
[7059] = "190/210/225/240",
[7060] = "190/210/225/240",
[7061] = "195/215/230/245",
[7062] = "195/215/225/235",
[7063] = "205/220/235/250",
[7064] = "210/225/240/255",
[7065] = "165/185/200/215",
[9998] = "205/220/235/250",
[9999] = "205/220/235/250",
[10001] = "210/225/240/255",
[10002] = "210/225/240/255",
[10003] = "215/230/245/260",
[10004] = "215/230/245/260",
[10007] = "215/230/245/260",
[10008] = "215/220/225/230",
[10009] = "215/230/245/260",
[10018] = "225/240/255/270",
[10019] = "225/240/255/270",
[10021] = "225/240/255/270",
[10023] = "225/240/255/270",
[10024] = "230/245/260/275",
[10025] = "245/260/275/290",
[10026] = "230/245/260/275",
[10027] = "230/245/260/275",
[10028] = "235/250/265/280",
[10029] = "235/250/265/280",
[10030] = "240/255/270/285",
[10031] = "240/255/270/285",
[10033] = "240/255/270/285",
[10034] = "240/245/250/255",
[10035] = "245/250/255/260",
[10036] = "250/265/280/295",
[10040] = "250/255/260/265",
[10041] = "250/265/280/295",
[10042] = "225/240/255/270",
[10044] = "245/260/275/290",
[10045] = "1/35/47/60",
[10046] = "20/50/67/85",
[10047] = "75/100/117/135",
[10048] = "120/145/162/180",
[10050] = "225/240/255/270",
[10051] = "235/250/265/280",
[10052] = "220/225/230/235",
[10053] = "235/240/245/250",
[10054] = "230/235/240/245",
[10055] = "235/240/245/250",
[10056] = "215/220/225/230",
[13856] = "255/270/285/300",
[13857] = "260/275/290/305",
[13858] = "260/275/290/305",
[13860] = "265/280/295/310",
[13863] = "275/290/305/320",
[13864] = "280/295/310/325",
[13865] = "285/300/315/330",
[13866] = "295/310/325/340",
[13867] = "300/315/330/345",
[13868] = "255/270/285/300",
[13869] = "255/270/285/300",
[13870] = "265/280/295/310",
[13871] = "280/295/310/325",
[14042] = "260/275/290/305",
[14043] = "270/285/300/315",
[14044] = "275/290/305/320",
[14045] = "280/295/310/325",
[14046] = "260/275/290/305",
[14048] = "250/255/257/260",
[14100] = "270/285/300/315",
[14101] = "270/285/300/315",
[14103] = "275/290/305/320",
[14104] = "290/305/320/335",
[14106] = "300/315/330/345",
[14107] = "275/290/305/320",
[14108] = "285/300/315/330",
[14111] = "290/305/320/335",
[14112] = "300/315/330/345",
[14128] = "300/315/330/345",
[14130] = "300/315/330/345",
[14132] = "275/290/305/320",
[14134] = "275/290/305/320",
[14136] = "285/300/315/330",
[14137] = "290/305/320/335",
[14138] = "300/315/330/345",
[14139] = "300/315/330/345",
[14140] = "300/315/330/345",
[14141] = "275/290/305/320",
[14142] = "270/285/300/315",
[14143] = "265/280/295/310",
[14144] = "290/305/320/335",
[14146] = "300/315/330/345",
[14152] = "300/315/330/345",
[14153] = "300/315/330/345",
[14154] = "300/315/330/345",
[14155] = "300/315/330/345",
[14156] = "300/315/330/345",
[14342] = "250/290/305/320",
[15802] = "290/295/310/325",
[16979] = "300/315/330/345",
[16980] = "300/315/330/345",
[17723] = "190/200/205/210",
[18258] = "285/285/290/295",
[18263] = "300/320/335/350",
[18405] = "300/315/330/345",
[18407] = "300/315/330/345",
[18408] = "300/315/330/345",
[18409] = "300/315/330/345",
[18413] = "300/315/330/345",
[18486] = "300/315/330/345",
[19047] = "290/305/320/335",
[19050] = "300/315/330/345",
[19056] = "290/305/320/335",
[19059] = "300/315/330/345",
[19156] = "300/315/330/345",
[19165] = "300/315/330/345",
[19682] = "300/315/330/345",
[19683] = "300/315/330/345",
[19684] = "300/315/330/345",
[20537] = "300/315/330/345",
[20538] = "300/315/330/345",
[20539] = "300/315/330/345",
[21154] = "250/265/280/295",
[21340] = "260/275/290/305",
[21341] = "285/300/315/330",
[21342] = "300/315/330/345",
[21542] = "250/265/280/295",
[21840] = "300/305/315/325",
[21841] = "315/320/330/340",
[21842] = "325/330/335/340",
[21843] = "340/340/345/350",
[21844] = "345/345/350/355",
[21845] = "350/350/355/360",
[21846] = "355/365/370/375",
[21847] = "365/375/380/385",
[21848] = "375/385/390/395",
[21849] = "310/320/325/330",
[21850] = "310/320/325/330",
[21851] = "320/330/335/340",
[21852] = "325/335/340/345",
[21853] = "335/345/350/355",
[21854] = "340/350/355/360",
[21855] = "345/355/360/365",
[21858] = "375/385/390/395",
[21859] = "340/350/355/360",
[21860] = "350/360/365/370",
[21861] = "360/370/375/380",
[21862] = "360/370/375/380",
[21863] = "355/365/370/375",
[21864] = "365/375/380/385",
[21865] = "375/380/382/385",
[21866] = "350/360/365/370",
[21867] = "360/370/375/380",
[21868] = "370/380/385/390",
[21869] = "355/365/370/375",
[21870] = "365/375/380/385",
[21871] = "375/385/390/395",
[21872] = "375/385/390/395",
[21873] = "355/365/370/375",
[21874] = "365/375/380/385",
[21875] = "375/385/390/395",
[21876] = "375/385/390/395",
[22246] = "225/240/255/270",
[22248] = "275/290/305/320",
[22249] = "300/315/330/345",
[22251] = "275/290/305/320",
[22252] = "300/315/330/345",
[22652] = "300/315/330/345",
[22654] = "300/315/330/345",
[22655] = "300/315/330/345",
[22658] = "300/315/330/345",
[22660] = "300/315/330/345",
[22756] = "300/315/330/345",
[22757] = "300/315/330/345",
[22758] = "300/315/330/345",
[24249] = "350/360/365/370",
[24250] = "350/360/365/370",
[24251] = "350/360/365/370",
[24252] = "350/360/365/370",
[24253] = "350/360/365/370",
[24254] = "350/360/365/370",
[24255] = "365/375/380/385",
[24256] = "365/375/380/385",
[24257] = "365/375/380/385",
[24258] = "365/375/380/385",
[24259] = "365/375/380/385",
[24260] = "365/375/380/385",
[24261] = "375/385/390/395",
[24262] = "375/385/390/395",
[24263] = "375/385/390/395",
[24264] = "375/385/390/395",
[24266] = "375/385/390/395",
[24267] = "375/385/390/395",
[24268] = "300/300/310/320",
[24270] = "340/350/355/360",
[24271] = "350/350/355/360",
[24272] = "350/350/355/360",
[24273] = "335/345/350/355",
[24274] = "375/385/390/395",
[24275] = "335/345/350/355",
[24276] = "375/385/390/395",
[30035] = "375/385/390/395",
[30036] = "375/385/390/395",
[30037] = "375/385/390/395",
[30038] = "375/385/390/395",
[30831] = "350/360/365/370",
[30837] = "350/360/365/370",
[30838] = "360/370/375/380",
[30839] = "370/380/385/390",
[32389] = "375/385/390/395",
[32390] = "375/385/390/395",
[32391] = "375/385/390/395",
[32392] = "375/385/390/395",
[32420] = "375/385/390/395",
[32584] = "375/385/390/395",
[32585] = "375/385/390/395",
[32586] = "375/385/390/395",
[32587] = "375/385/390/395",
[34085] = "250/250/250/250",
[34087] = "250/250/250/250",
[34364] = "365/375/392/410",
[34365] = "365/375/392/410",
[34366] = "365/375/392/410",
[34367] = "365/375/392/410",
[38225] = "375/385/390/395",
[38277] = "250/265/280/295",
[38278] = "245/250/255/260",
[41248] = "400/400/405/410",
[41249] = "400/400/405/410",
[41250] = "400/400/405/410",
[41251] = "400/400/405/410",
[41252] = "400/400/405/410",
[41253] = "400/400/405/410",
[41254] = "400/400/405/410",
[41255] = "400/400/405/410",
[41509] = "360/370/375/380",
[41510] = "350/370/372/375",
[41511] = "400/400/402/405",
[41512] = "350/360/370/380",
[41513] = "350/360/370/380",
[41515] = "360/370/380/390",
[41516] = "420/430/440/450",
[41519] = "380/390/400/410",
[41520] = "375/385/395/405",
[41521] = "380/390/400/410",
[41522] = "370/380/390/400",
[41523] = "385/395/405/415",
[41525] = "390/400/410/420",
[41528] = "385/395/405/415",
[41543] = "395/400/405/410",
[41544] = {[55924] = "410/420/425/430", [56048] = "400/400/410/420"},
[41545] = "405/415/420/425",
[41546] = "395/405/410/415",
[41548] = "395/405/410/415",
[41549] = "405/415/420/425",
[41550] = "410/420/425/430",
[41551] = "400/410/415/420",
[41553] = "415/425/430/435",
[41554] = "420/430/435/440",
[41555] = "415/425/430/435",
[41593] = "415/425/430/435",
[41594] = "415/425/430/435",
[41595] = "415/425/430/435",
[41597] = "435/440/445/450",
[41598] = "440/445/450/455",
[41599] = "410/430/440/450",
[41600] = "445/450/455/460",
[41601] = "400/400/405/410",
[41602] = "430/435/440/445",
[41603] = "400/400/405/410",
[41604] = "430/435/440/445",
[41607] = "390/395/400/405",
[41608] = "395/400/405/410",
[41609] = "415/435/445/455",
[41610] = "420/435/445/455",
[41984] = "425/435/440/445",
[41985] = "420/430/440/450",
[41986] = "420/430/440/450",
[42093] = "425/435/440/445",
[42095] = "420/430/440/450",
[42096] = "420/430/440/450",
[42100] = "440/450/455/460",
[42101] = "440/450/455/460",
[42102] = "440/450/455/460",
[42103] = "435/445/450/455",
[42111] = "435/445/450/455",
[42113] = "435/445/450/455",
[43583] = "425/435/445/455",
[43584] = "420/430/440/450",
[43585] = "420/430/440/450",
[43969] = "415/425/435/445",
[43970] = "420/430/440/450",
[43971] = "420/430/440/450",
[43972] = "420/430/440/450",
[43973] = "420/430/440/450",
[43974] = "415/425/435/445",
[43975] = "420/430/440/450",
[44211] = "360/370/380/390",
[44554] = "300/340/345/350",
[44558] = "425/435/445/455",
[45557] = "450/455/460/465",
[45558] = "450/455/460/465",
[45566] = "450/455/460/465",
[45567] = "450/455/460/465",
[45626] = "125/150/167/185",
[45773] = "435/440/445/450",
[45810] = "405/410/415/420",
[45811] = "400/405/410/415",
[47585] = "450/460/467/475",
[47586] = "450/460/467/475",
[47587] = "450/460/467/475",
[47588] = "450/460/467/475",
[47603] = "450/460/467/475",
[47604] = "450/460/467/475",
[47605] = "450/460/467/475",
[47606] = "450/460/467/475",
[49890] = "450/475/487/500",
[49891] = "450/475/487/500",
[49892] = "450/475/487/500",
[49893] = "450/475/487/500",
[54797] = "425/435/445/455",
		
-- https://wotlk.wowhead.com/cooking#recipes
-- number recipes: 174
[724] = "50/90/110/130",
[733] = "75/115/135/155",
[787] = "1/45/65/85",
[1017] = "100/140/160/180",
[1082] = "100/135/155/175",
[2679] = "1/45/65/85",
[2680] = "10/50/70/90",
[2681] = "1/45/65/85",
[2682] = "85/125/145/165",
[2683] = "75/115/135/155",
[2684] = "50/90/110/130",
[2685] = "110/130/150/170",
[2687] = "80/120/140/160",
[2888] = "25/60/80/100",
[3220] = "60/100/120/140",
[3662] = "80/120/140/160",
[3663] = "90/130/150/170",
[3664] = "120/160/180/200",
[3665] = "130/170/190/210",
[3666] = "110/150/170/190",
[3726] = "110/150/170/190",
[3727] = "125/175/195/215",
[3728] = "150/190/210/230",
[3729] = "175/215/235/255",
[4457] = "175/215/235/255",
[4592] = "50/90/110/130",
[4593] = "100/140/160/180",
[4594] = "175/190/210/230",
[5095] = "50/90/110/130",
[5472] = "10/50/70/90",
[5473] = "20/60/80/100",
[5474] = "35/75/95/115",
[5476] = "50/90/110/130",
[5477] = "50/90/110/130",
[5478] = "90/130/150/170",
[5479] = "100/140/160/180",
[5480] = "110/150/170/190",
[5525] = "50/90/110/130",
[5526] = "90/130/150/170",
[5527] = "125/165/185/205",
[6038] = "175/215/235/255",
[6290] = "1/45/65/85",
[6316] = "50/90/110/130",
[6657] = "85/125/145/165",
[6887] = "225/250/262/275",
[6888] = "1/45/65/85",
[6890] = "40/80/100/120",
[7676] = "60/100/120/140",
[8364] = "175/215/235/255",
[10841] = "175/175/190/205",
[12209] = "125/165/185/205",
[12210] = "175/215/235/255",
[12212] = "175/215/235/255",
[12213] = "175/215/235/255",
[12214] = "175/215/235/255",
[12215] = "200/225/237/250",
[12216] = "225/250/262/275",
[12217] = "200/225/237/250",
[12218] = "225/250/262/275",
[12224] = "1/45/65/85",
[13851] = "175/215/235/255",
[13927] = "225/250/262/275",
[13928] = "240/265/277/290",
[13929] = "240/265/277/290",
[13930] = "225/250/262/275",
[13931] = "250/275/285/295",
[13932] = "250/275/285/295",
[13933] = "275/300/312/325",
[13934] = "275/300/312/325",
[13935] = "275/300/312/325",
[16766] = "225/250/262/275",
[17197] = "1/45/65/85",
[17198] = "35/75/95/115",
[17222] = "200/225/237/250",
[18045] = "225/250/262/275",
[18254] = "275/300/312/325",
[20074] = "150/160/180/200",
[20452] = "285/310/322/335",
[21023] = "300/325/337/350",
[21072] = "80/120/140/160",
[21217] = "175/215/235/255",
[22645] = "60/100/120/140",
[24105] = "1/45/65/85",
[27635] = "1/45/65/85",
[27636] = "50/90/110/130",
[27651] = "300/320/330/340",
[27655] = "300/320/330/340",
[27656] = "310/330/340/350",
[27657] = "315/335/345/355",
[27658] = "325/345/355/365",
[27659] = "325/345/355/365",
[27660] = "325/345/355/365",
[27661] = "300/320/330/340",
[27662] = "300/320/330/340",
[27663] = "310/330/340/350",
[27664] = "320/340/350/360",
[27665] = "320/340/350/360",
[27666] = "325/345/355/365",
[27667] = "350/370/375/380",
[30155] = "300/320/330/340",
[30816] = "1/30/35/40",
[31672] = "335/355/365/375",
[31673] = "335/355/365/375",
[33004] = "250/250/275/300",
[33048] = "335/335/345/355",
[33052] = "375/375/380/385",
[33053] = "375/375/380/385",
[33825] = "325/335/345/355",
[33866] = "300/320/330/340",
[33867] = "300/320/330/340",
[33872] = "325/335/345/355",
[33874] = "300/345/355/365",
[33924] = "1/50/62/75",
[34411] = "325/325/325/325",
[34747] = "350/350/365/380",
[34748] = "350/350/382/415",
[34749] = "350/350/382/415",
[34750] = "350/350/382/415",
[34751] = "350/350/382/415",
[34752] = "350/350/382/415",
[34753] = "375/375/400/425",
[34754] = "400/425/450/475",
[34755] = "400/425/450/475",
[34756] = "400/425/450/475",
[34757] = "400/425/450/475",
[34758] = "400/425/450/475",
[34759] = "350/350/365/380",
[34760] = "350/350/365/380",
[34761] = "350/350/365/380",
[34762] = "350/350/382/415",
[34763] = "350/350/382/415",
[34764] = "350/350/382/415",
[34765] = "350/350/382/415",
[34766] = "400/425/450/475",
[34767] = "400/425/450/475",
[34768] = "400/425/450/475",
[34769] = "400/425/450/475",
[34832] = "100/100/105/110",
[35563] = "250/275/285/295",
[35565] = "250/275/285/295",
[39520] = "350/375/387/400",
[42942] = "350/350/382/415",
[42993] = "400/425/450/475",
[42994] = "400/425/450/475",
[42995] = "400/425/450/475",
[42996] = "400/425/450/475",
[42997] = "400/425/450/475",
[42998] = "400/425/450/475",
[42999] = "400/425/450/475",
[43000] = "400/425/450/475",
[43001] = "400/425/450/475",
[43004] = "400/425/450/475",
[43005] = "400/425/450/475",
[43015] = "450/455/460/465",
[43268] = "350/350/382/415",
[43478] = "425/435/455/475",
[43480] = "425/435/455/475",
[43488] = "350/350/357/365",
[43490] = "350/350/357/365",
[43491] = "350/350/357/365",
[43492] = "350/350/357/365",
[44836] = {[62044] = "100/150/162/175", [66036] = "100/150/162/175"},
[44837] = {[62050] = "1/90/102/115", [66038] = "1/90/102/115"},
[44838] = {[62045] = "280/330/342/355", [66037] = "280/330/342/355"},
[44839] = {[62051] = "220/270/282/295", [66034] = "220/270/282/295"},
[44840] = {[62049] = "160/210/222/235", [66035] = "160/210/222/235"},
[44953] = "400/400/405/460",
[45932] = "400/400/412/425",
[46691] = "1/30/35/40",
		
-- https://wotlk.wowhead.com/inscription#recipes
-- skipping spellID: 57231 - Death Knight Glyph 25
-- number recipes: 443
[-61117] = "400/400/400/405",
[-61118] = "400/400/400/405",
[-61119] = "400/400/400/405",
[-61120] = "400/400/400/405",
[-61177] = "385/425/437/450",
[-61288] = "75/125/137/150",
[954] = "15/35/40/45",
[955] = "35/35/40/45",
[1180] = "35/35/40/45",
[1181] = "35/35/40/45",
[1477] = "85/85/90/95",
[1711] = "75/75/80/85",
[1712] = "75/75/80/85",
[2289] = "80/80/85/90",
[2290] = "75/75/80/85",
[3012] = "15/35/40/45",
[4419] = "165/170/175/180",
[4422] = "155/160/165/170",
[4424] = "160/165/170/175",
[4425] = "175/180/185/190",
[4426] = "170/175/180/185",
[10306] = "210/215/220/225",
[10307] = "205/210/215/220",
[10308] = "215/220/225/230",
[10309] = "225/230/235/240",
[10310] = "220/225/230/235",
[27498] = "270/275/280/285",
[27499] = "260/265/270/275",
[27501] = "255/260/265/270",
[27502] = "250/255/260/265",
[27503] = "265/270/275/280",
[33457] = "310/320/325/330",
[33458] = "310/310/315/320",
[33460] = "295/305/310/315",
[33461] = "290/300/305/310",
[33462] = "305/315/320/325",
[37091] = "360/365/370/375",
[37092] = "410/415/420/425",
[37093] = "350/355/360/365",
[37094] = "400/405/410/415",
[37097] = "355/360/365/370",
[37098] = "405/410/415/420",
[37101] = "15/15/22/30",
[37118] = "35/60/67/75",
[37168] = "110/125/137/150",
[37602] = "200/210/215/220",
[38322] = "400/425/437/450",
[38682] = "35/75/87/100",
[39349] = "75/100/112/125",
[39350] = "235/250/255/260",
[39469] = "35/45/60/75",
[39774] = "75/75/77/80",
[40896] = "350/355/360/365",
[40897] = "90/100/110/120",
[40899] = "385/390/397/405",
[40900] = "385/390/397/405",
[40901] = "260/265/270/275",
[40902] = "200/205/210/215",
[40903] = "310/315/320/325",
[40906] = "385/390/397/405",
[40908] = "385/390/397/405",
[40909] = "170/175/180/185",
[40912] = "385/390/397/405",
[40913] = "80/90/100/110",
[40914] = "115/120/125/130",
[40915] = "385/390/397/405",
[40916] = "220/225/230/235",
[40919] = "150/155/160/165",
[40920] = "385/390/397/405",
[40921] = "385/390/397/405",
[40922] = "85/95/105/115",
[40923] = "130/135/140/145",
[40924] = "100/105/110/115",
[41092] = "120/125/130/135",
[41094] = "335/340/345/350",
[41095] = "90/100/110/120",
[41096] = "80/90/100/110",
[41097] = "385/390/397/405",
[41098] = "230/235/240/245",
[41099] = "205/210/215/220",
[41100] = "155/160/165/170",
[41101] = "385/390/397/405",
[41102] = "375/380/385/390",
[41103] = "265/270/275/280",
[41104] = "180/185/190/195",
[41105] = "300/305/310/315",
[41106] = "105/110/115/120",
[41107] = "385/390/397/405",
[41108] = "135/140/145/150",
[41109] = "385/390/397/405",
[41110] = "385/390/397/405",
[41517] = "385/390/397/405",
[41518] = "385/390/397/405",
[41524] = "385/390/395/400",
[41526] = "385/390/397/405",
[41527] = "300/305/310/315",
[41529] = "385/390/397/405",
[41530] = "110/115/120/125",
[41531] = "85/95/105/115",
[41532] = "125/130/135/140",
[41533] = "215/220/225/230",
[41534] = "385/390/397/405",
[41535] = "235/240/245/250",
[41536] = "140/145/150/155",
[41537] = "95/105/115/125",
[41538] = "385/390/397/405",
[41539] = "375/380/385/390",
[41540] = "165/170/175/180",
[41541] = "275/280/285/290",
[41542] = "330/335/340/345",
[41547] = "185/190/195/200",
[41552] = "385/390/397/405",
[42396] = "385/390/397/405",
[42397] = "230/235/240/245",
[42398] = "105/110/115/120",
[42399] = "270/275/280/285",
[42400] = "120/125/130/135",
[42401] = "315/320/325/330",
[42402] = "135/140/145/150",
[42403] = "385/390/397/405",
[42404] = "385/390/397/405",
[42405] = "385/390/397/405",
[42406] = "350/355/360/365",
[42407] = "385/390/397/405",
[42408] = "80/90/100/110",
[42409] = "385/390/397/405",
[42410] = "95/105/115/125",
[42411] = "160/165/170/175",
[42412] = "375/380/385/390",
[42414] = "385/390/397/405",
[42415] = "180/185/190/195",
[42416] = "210/215/220/225",
[42417] = "385/390/397/405",
[42453] = "350/355/360/365",
[42454] = "385/390/397/405",
[42455] = "85/95/105/115",
[42456] = "385/390/397/405",
[42457] = "385/390/397/405",
[42458] = "125/130/135/140",
[42459] = "385/390/397/405",
[42460] = "385/390/397/405",
[42461] = "110/115/120/125",
[42462] = "95/105/115/125",
[42463] = "385/390/397/405",
[42464] = "385/390/397/405",
[42465] = "140/145/150/155",
[42466] = "215/220/225/230",
[42467] = "165/170/175/180",
[42468] = "275/280/285/290",
[42469] = "385/390/397/405",
[42470] = "240/245/250/255",
[42471] = "325/330/335/340",
[42472] = "385/390/397/405",
[42473] = "190/195/200/205",
[42734] = "100/105/110/115",
[42735] = "115/120/125/130",
[42736] = "335/340/345/350",
[42737] = "130/135/140/145",
[42738] = "155/160/165/170",
[42739] = "385/390/397/405",
[42740] = "385/390/397/405",
[42741] = "80/90/100/110",
[42742] = "385/390/397/405",
[42743] = "90/100/110/120",
[42744] = "225/230/235/240",
[42745] = "375/380/385/390",
[42746] = "175/180/185/190",
[42747] = "205/210/215/220",
[42748] = "385/390/397/405",
[42749] = "325/330/335/340",
[42750] = "280/285/290/295",
[42751] = "385/390/397/405",
[42752] = "400/400/400/405",
[42753] = "385/390/397/405",
[42754] = "385/390/397/405",
[42897] = "175/180/185/190",
[42898] = "100/105/110/115",
[42899] = "385/390/397/405",
[42900] = "115/120/125/130",
[42901] = "385/390/397/405",
[42902] = "385/390/397/405",
[42903] = "200/205/210/215",
[42904] = "225/230/235/240",
[42905] = "260/265/270/275",
[42906] = "350/355/360/365",
[42907] = "80/90/100/110",
[42908] = "130/135/140/145",
[42909] = "375/380/385/390",
[42910] = "150/155/160/165",
[42911] = "315/320/325/330",
[42912] = "90/100/110/120",
[42913] = "385/390/397/405",
[42914] = "385/390/397/405",
[42915] = "385/390/397/405",
[42916] = "385/390/397/405",
[42917] = "385/390/397/405",
[42954] = "385/390/397/405",
[42955] = "340/345/350/355",
[42956] = "80/90/100/110",
[42957] = "385/390/397/405",
[42958] = "385/390/397/405",
[42959] = "385/390/397/405",
[42960] = "95/105/115/125",
[42961] = "105/110/115/120",
[42962] = "120/125/130/135",
[42963] = "305/310/315/320",
[42964] = "135/140/145/150",
[42965] = "385/390/397/405",
[42966] = "160/165/170/175",
[42967] = "385/390/397/405",
[42968] = "385/390/397/405",
[42969] = "385/390/397/405",
[42970] = "185/190/195/200",
[42971] = "385/390/397/405",
[42972] = "210/215/220/225",
[42973] = "235/240/245/250",
[42974] = "285/290/295/300",
[43115] = "85/85/90/95",
[43116] = "100/100/100/105",
[43117] = "125/125/130/135",
[43118] = "150/150/150/155",
[43119] = "175/175/175/180",
[43120] = "200/200/200/205",
[43121] = "225/225/225/230",
[43122] = "250/250/250/255",
[43123] = "275/290/295/300",
[43124] = "290/295/300/305",
[43125] = "325/325/325/330",
[43126] = "350/350/350/355",
[43127] = "375/375/375/380",
[43145] = "350/355/370/385",
[43146] = "400/405/410/415",
[43316] = "75/105/110/115",
[43331] = "75/105/110/115",
[43332] = "75/80/85/90",
[43334] = "75/155/160/165",
[43335] = "75/80/85/90",
[43338] = "75/80/85/90",
[43339] = "75/80/85/90",
[43340] = "75/80/85/90",
[43342] = "75/80/85/90",
[43343] = "75/80/85/90",
[43344] = "75/130/135/140",
[43350] = "75/80/85/90",
[43351] = "75/155/160/165",
[43354] = "75/80/85/90",
[43355] = "75/205/210/215",
[43356] = "75/80/85/90",
[43357] = "75/105/110/115",
[43359] = "75/80/85/90",
[43360] = "75/130/135/140",
[43361] = "75/80/85/90",
[43364] = "75/80/85/90",
[43365] = "75/105/110/115",
[43366] = "75/80/85/90",
[43367] = "75/80/85/90",
[43368] = "75/105/110/115",
[43369] = "75/155/160/165",
[43370] = "75/180/185/190",
[43371] = "75/80/85/90",
[43372] = "75/155/160/165",
[43373] = "75/105/110/115",
[43374] = "75/355/360/365",
[43376] = "75/130/135/140",
[43377] = "75/105/110/115",
[43378] = "75/205/210/215",
[43379] = "75/80/85/90",
[43380] = "75/130/135/140",
[43381] = "75/155/160/165",
[43385] = "75/155/160/165",
[43386] = "75/105/110/115",
[43388] = "75/155/160/165",
[43389] = "75/105/110/115",
[43390] = "75/80/85/90",
[43391] = "75/130/135/140",
[43392] = "75/155/160/165",
[43393] = "75/155/160/165",
[43394] = "75/355/360/365",
[43395] = "75/80/85/90",
[43396] = "75/80/85/90",
[43397] = "75/80/85/90",
[43398] = "75/105/110/115",
[43399] = "75/80/85/90",
[43400] = "75/330/335/340",
[43412] = "385/390/397/405",
[43413] = "85/95/105/115",
[43414] = "240/245/250/255",
[43415] = "385/390/397/405",
[43416] = "285/290/295/300",
[43417] = "125/130/135/140",
[43418] = "95/105/115/125",
[43419] = "385/390/397/405",
[43420] = "220/225/230/235",
[43421] = "385/390/397/405",
[43422] = "170/175/180/185",
[43423] = "110/115/120/125",
[43424] = "190/195/200/205",
[43425] = "385/390/397/405",
[43426] = "385/390/397/405",
[43427] = "140/145/150/155",
[43428] = "320/325/330/335",
[43429] = "385/390/397/405",
[43430] = "385/390/397/405",
[43431] = "385/390/397/405",
[43432] = "345/350/355/360",
[43463] = "370/375/380/385",
[43464] = "420/425/430/435",
[43465] = "365/370/375/380",
[43466] = "415/420/425/430",
[43515] = "110/125/137/150",
[43533] = "385/390/397/405",
[43534] = "385/390/397/405",
[43535] = "75/330/335/340",
[43536] = "265/270/275/280",
[43537] = "385/390/397/405",
[43538] = "385/390/397/405",
[43539] = "75/305/310/315",
[43541] = "285/290/295/300",
[43542] = "385/390/397/405",
[43543] = "270/275/280/285",
[43544] = "75/330/335/340",
[43545] = "385/390/397/405",
[43546] = "280/285/290/295",
[43547] = "385/390/397/405",
[43548] = "300/305/310/315",
[43549] = "350/355/360/365",
[43550] = "385/390/397/405",
[43551] = "330/335/340/345",
[43552] = "375/380/385/390",
[43553] = "305/310/315/320",
[43554] = "345/350/355/360",
[43654] = "125/150/162/175",
[43655] = "125/150/162/175",
[43656] = "175/200/205/210",
[43657] = "175/200/205/210",
[43660] = "225/240/245/250",
[43661] = "225/240/245/250",
[43663] = "275/290/295/300",
[43664] = "275/290/295/300",
[43666] = "325/340/345/350",
[43667] = "325/340/345/350",
[43671] = "75/305/310/315",
[43672] = "75/305/310/315",
[43673] = "75/305/310/315",
[43674] = "75/155/160/165",
[43725] = "75/105/110/115",
[43825] = "310/315/320/325",
[43826] = "320/325/330/335",
[43827] = "340/345/350/355",
[43850] = "200/205/210/215",
[43867] = "385/390/397/405",
[43868] = "385/390/397/405",
[43869] = "385/390/397/405",
[44142] = "125/150/162/175",
[44161] = "175/200/205/210",
[44163] = "225/240/245/250",
[44210] = "400/425/437/450",
[44314] = "200/215/220/225",
[44315] = "350/350/350/355",
[44316] = "275/290/295/300",
[44317] = "325/350/365/380",
[44318] = "400/450/462/475",
[44684] = "385/390/397/405",
[44920] = "75/355/360/365",
[44922] = "75/355/360/365",
[44923] = "75/355/360/365",
[44928] = "375/380/385/390",
[44955] = "315/320/325/330",
[45601] = "430/430/435/440",
[45602] = "430/430/435/440",
[45603] = "430/430/435/440",
[45604] = "430/430/435/440",
[45622] = "250/255/262/270",
[45623] = "430/430/435/440",
[45625] = "430/430/435/440",
[45731] = "430/430/435/440",
[45732] = "430/430/435/440",
[45733] = "430/430/435/440",
[45734] = "430/430/435/440",
[45735] = "430/430/435/440",
[45736] = "430/430/435/440",
[45737] = "430/430/435/440",
[45738] = "430/430/435/440",
[45739] = "430/430/435/440",
[45740] = "430/430/435/440",
[45741] = "430/430/435/440",
[45742] = "430/430/435/440",
[45743] = "430/430/435/440",
[45744] = "430/430/435/440",
[45745] = "430/430/435/440",
[45746] = "430/430/435/440",
[45747] = "430/430/435/440",
[45753] = "430/430/435/440",
[45755] = "430/430/435/440",
[45756] = "430/430/435/440",
[45757] = "430/430/435/440",
[45758] = "430/430/435/440",
[45760] = "255/255/262/270",
[45761] = "430/430/435/440",
[45762] = "430/430/435/440",
[45764] = "430/430/435/440",
[45766] = "430/430/435/440",
[45767] = "430/430/435/440",
[45768] = "255/255/262/270",
[45769] = "430/430/435/440",
[45770] = "430/430/435/440",
[45771] = "430/430/435/440",
[45772] = "430/430/435/440",
[45775] = "250/255/262/270",
[45776] = "255/255/262/270",
[45777] = "430/430/435/440",
[45778] = "430/430/435/440",
[45779] = "430/430/435/440",
[45780] = "430/430/435/440",
[45781] = "430/430/435/440",
[45782] = "430/430/435/440",
[45783] = "430/430/435/440",
[45785] = "430/430/435/440",
[45789] = "430/430/435/440",
[45790] = "430/430/435/440",
[45792] = "430/430/435/440",
[45793] = "430/430/435/440",
[45794] = "75/430/435/440",
[45795] = "430/430/435/440",
[45797] = "430/430/435/440",
[45799] = "430/430/435/440",
[45800] = "430/430/435/440",
[45803] = "430/430/435/440",
[45804] = "275/280/287/295",
[45805] = "280/285/290/295",
[45806] = "430/430/435/440",
[45849] = "350/375/387/400",
[45854] = "350/375/387/400",
[46372] = "430/430/435/440",
[48720] = "100/105/110/115",
[49084] = "75/355/360/365",
[49632] = "440/440/442/460",
[50045] = "250/255/260/265",
[50077] = "375/380/382/385",
[50125] = "375/380/382/385",
[204385] = "390/390/397/405",
[206580] = "390/390/397/405",
[206953] = "390/390/397/405",

-- https://wotlk.wowhead.com/first-aid#recipes
-- number recipes: 17
[1251] = "1/30/45/60",
[2581] = "40/50/75/100",
[3530] = "80/80/115/150",
[3531] = "115/115/150/185",
[6450] = "150/150/180/210",
[6451] = "180/180/210/240",
[6452] = "80/80/115/150",
[6453] = "130/130/165/200",
[8544] = "210/210/240/270",
[8545] = "240/240/270/300",
[14529] = "260/260/290/320",
[14530] = "290/290/320/350",
[19440] = "300/300/330/360",
[21990] = "300/330/347/365",
[21991] = "330/360/367/375",
[34721] = "350/375/392/410",
[34722] = "400/400/430/470",
	}
end
